# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdTree(Component):
    """An AntdTree component.
    树形控件组件AntdTree

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - treeDataMode (a value equal to: 'tree', 'flat'; default 'tree'):
        对应`treeData`格式的渲染模式，可选项有`'tree'`（树形模式）、`'flat'`（扁平模式）
        默认值：`'tree'`.

    - treeData (list; optional):
        定义构造树所需的数据结构，与`treeDataMode`一致.

    - treeNodeKeyToTitle (dict with strings as keys and values of type a list of or a singular dash component, string or number; optional):
        针对树结构中的指定节点，定义作为标题的组件型内容，优先级高于`treeData`中对应的`title`值.

    - showIcon (boolean; default False):
        是否渲染节点额外图标 默认值：`False`.

    - selectable (boolean; default True):
        节点是否可点击选择 默认值：`True`.

    - multiple (boolean; default False):
        节点是否允许多选 默认值：`False`.

    - checkable (boolean; default False):
        节点是否可勾选 默认值：`False`.

    - defaultExpandAll (boolean; default False):
        初始化是否展开全部节点 默认值：`False`.

    - expandedKeys (list of strings; optional):
        监听或设置已展开节点`key`值数组.

    - defaultExpandedKeys (list of strings; optional):
        初始化已展开节点`key`值数组.

    - defaultExpandParent (boolean; default False):
        初始化是否展开处于展开状态节点的父节点 默认值：`True`.

    - selectedKeys (list of strings; optional):
        监听或设置已选择节点`key`值数组.

    - defaultSelectedKeys (list of strings; optional):
        初始化已选择节点`key`值数组.

    - checkedKeys (list of strings; optional):
        监听或设置已勾选节点`key`值数组.

    - defaultCheckedKeys (list of strings; optional):
        初始化已勾选节点`key`值数组.

    - halfCheckedKeys (list of strings; optional):
        监听或设置处于半勾选状态下的节点`key`值数组.

    - checkStrictly (boolean; default False):
        节点与其后代节点之间的选择行为是否彼此独立 默认值：`False`.

    - showLine (dict; default { showLeafIcon: False }):
        是否显示连接线.

        `showLine` is a boolean | dict with keys:

        - showLeafIcon (boolean; optional):
            叶节点是否渲染前缀图标.

    - switcherIcon (a list of or a singular dash component, string or number; optional):
        组件型，自定义树节点的展开/折叠图标.

    - height (number; optional):
        虚拟滚动模式下的组件最大像素高度，未设置时则不启用虚拟滚动功能.

    - draggable (boolean; default False):
        节点是否可拖拽 默认值：`False`.

    - showDragIcon (boolean; default True):
        开启节点拖拽功能后，是否为节点渲染拖拽图标 默认值：`True`.

    - dragInSameLevel (boolean; default False):
        当`draggable=True`时，是否仅允许同级拖拽 默认值：`False`.

    - dragDisabledKeys (list of strings; optional):
        禁止进行拖拽调整的节点`key`值数组 默认值：`[]`.

    - dropDisabledKeys (list of strings; optional):
        禁止进行拖拽放置的节点`key`值数组 默认值：`[]`.

    - draggedNodeKey (string; optional):
        监听最近一次被拖拽节点`key`值信息.

    - clickedContextMenu (dict; optional):
        监听节点右键菜单项点击事件.

        `clickedContextMenu` is a dict with keys:

        - nodeKey (string; optional):
            事件对应节点`key`值.

        - menuKey (string; optional):
            事件对应右键菜单项`key`值.

        - timestamp (number; optional):
            事件对应时间戳信息.

    - enableNodeFavorites (boolean; default False):
        是否启用节点收藏功能 默认值：`False`.

    - favoritedKeys (list of strings; optional):
        监听或设置已收藏节点`key`值数组.

    - scrollTarget (dict; optional):
        执行滚动到指定节点的动作，每次执行完毕后会重置为空值.

        `scrollTarget` is a dict with keys:

        - key (string; required):
            滚动目标节点`key`值.

        - align (a value equal to: 'top', 'bottom', 'auto'; optional):
            滚动目标节点对齐位置，可选项有`'top'`、`'bottom'`、`'auto'` 默认值：`'auto'`.

        - offset (number; optional):
            滚动后的像素偏移量.

    - searchKeyword (string | list of strings; optional):
        快捷树搜索功能对应的单个关键词，或由多个关键词构成的数组.

    - caseSensitive (boolean; default True):
        针对`searchKeyword`，是否大小写敏感 默认值：`True`.

    - highlightStyle (dict; default {    fontWeight: 'bold',    backgroundColor: 'transparent',    padding: 0,    color: '#ff5500',}):
        快捷树搜索关键词匹配部分的高亮样式.

    - nodeCheckedSuffix (a list of or a singular dash component, string or number; optional):
        组件型，节点勾选状态下的后缀元素.

    - nodeUncheckedSuffix (a list of or a singular dash component, string or number; optional):
        组件型，节点非勾选状态下的后缀元素.

    - nodeCheckedStyle (dict; optional):
        节点勾选状态下的css样式.

    - nodeUncheckedStyle (dict; optional):
        节点非勾选状态下的css样式.

    - enableAsyncLoad (boolean; default False):
        是否开启子节点异步加载功能，开启后无`children`属性，且未设置`isLeaf`为`True`的节点将可展开并触发`loadingNode`事件更新
        默认值：`False`.

    - loadingNode (dict; optional):
        监听触发异步数据加载的节点展开事件信息.

    - batchPropsNames (list of strings; optional):
        需要纳入[批量属性监听](/batch-props-values)的若干属性名.

    - batchPropsValues (dict; optional):
        监听`batchPropsNames`中指定的若干属性值.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配.

    - persistence (boolean | string | number; optional):
        是否开启[属性持久化](/prop-persistence).

    - persisted_props (list of a value equal to: 'selectedKeys', 'checkedKeys', 'expandedKeys', 'halfCheckedKeys's; optional):
        开启属性持久化功能的若干属性名，可选项有`'selectedKeys'`、`'checkedKeys'`、`'expandedKeys'`、`'halfCheckedKeys'`
        默认值：`['selectedKeys', 'checkedKeys', 'expandedKeys',
        'halfCheckedKeys']`.

    - persistence_type (a value equal to: 'local', 'session', 'memory'; optional):
        属性持久化存储类型，可选项有`'local'`（本地持久化），`'session'`（会话持久化），`'memory'`（内存持久化）
        默认值：`'local'`."""

    _children_props: typing.List[str] = [
        'treeNodeKeyToTitle{}',
        'switcherIcon',
        'nodeCheckedSuffix',
        'nodeUncheckedSuffix',
    ]
    _base_nodes = ['switcherIcon', 'nodeCheckedSuffix', 'nodeUncheckedSuffix', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdTree'
    ShowLine = TypedDict('ShowLine', {'showLeafIcon': NotRequired[bool]})

    ClickedContextMenu = TypedDict(
        'ClickedContextMenu',
        {
            'nodeKey': NotRequired[str],
            'menuKey': NotRequired[str],
            'timestamp': NotRequired[NumberType],
        },
    )

    ScrollTarget = TypedDict(
        'ScrollTarget',
        {
            'key': str,
            'align': NotRequired[Literal['top', 'bottom', 'auto']],
            'offset': NotRequired[NumberType],
        },
    )

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        treeDataMode: typing.Optional[Literal['tree', 'flat']] = None,
        treeData: typing.Optional[typing.Union[typing.Any, typing.Sequence[typing.Any]]] = None,
        treeNodeKeyToTitle: typing.Optional[
            typing.Dict[typing.Union[str, float, int], ComponentType]
        ] = None,
        showIcon: typing.Optional[bool] = None,
        selectable: typing.Optional[bool] = None,
        multiple: typing.Optional[bool] = None,
        checkable: typing.Optional[bool] = None,
        defaultExpandAll: typing.Optional[bool] = None,
        expandedKeys: typing.Optional[typing.Sequence[str]] = None,
        defaultExpandedKeys: typing.Optional[typing.Sequence[str]] = None,
        defaultExpandParent: typing.Optional[bool] = None,
        selectedKeys: typing.Optional[typing.Sequence[str]] = None,
        defaultSelectedKeys: typing.Optional[typing.Sequence[str]] = None,
        checkedKeys: typing.Optional[typing.Sequence[str]] = None,
        defaultCheckedKeys: typing.Optional[typing.Sequence[str]] = None,
        halfCheckedKeys: typing.Optional[typing.Sequence[str]] = None,
        checkStrictly: typing.Optional[bool] = None,
        showLine: typing.Optional[typing.Union[bool, 'ShowLine']] = None,
        switcherIcon: typing.Optional[ComponentType] = None,
        height: typing.Optional[NumberType] = None,
        draggable: typing.Optional[bool] = None,
        showDragIcon: typing.Optional[bool] = None,
        dragInSameLevel: typing.Optional[bool] = None,
        dragDisabledKeys: typing.Optional[typing.Sequence[str]] = None,
        dropDisabledKeys: typing.Optional[typing.Sequence[str]] = None,
        draggedNodeKey: typing.Optional[str] = None,
        clickedContextMenu: typing.Optional['ClickedContextMenu'] = None,
        enableNodeFavorites: typing.Optional[bool] = None,
        favoritedKeys: typing.Optional[typing.Sequence[str]] = None,
        scrollTarget: typing.Optional['ScrollTarget'] = None,
        searchKeyword: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        caseSensitive: typing.Optional[bool] = None,
        highlightStyle: typing.Optional[dict] = None,
        nodeCheckedSuffix: typing.Optional[ComponentType] = None,
        nodeUncheckedSuffix: typing.Optional[ComponentType] = None,
        nodeCheckedStyle: typing.Optional[dict] = None,
        nodeUncheckedStyle: typing.Optional[dict] = None,
        enableAsyncLoad: typing.Optional[bool] = None,
        loadingNode: typing.Optional[dict] = None,
        batchPropsNames: typing.Optional[typing.Sequence[str]] = None,
        batchPropsValues: typing.Optional[dict] = None,
        persistence: typing.Optional[typing.Union[bool, str, NumberType]] = None,
        persisted_props: typing.Optional[
            typing.Sequence[
                Literal['selectedKeys', 'checkedKeys', 'expandedKeys', 'halfCheckedKeys']
            ]
        ] = None,
        persistence_type: typing.Optional[Literal['local', 'session', 'memory']] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'treeDataMode',
            'treeData',
            'treeNodeKeyToTitle',
            'showIcon',
            'selectable',
            'multiple',
            'checkable',
            'defaultExpandAll',
            'expandedKeys',
            'defaultExpandedKeys',
            'defaultExpandParent',
            'selectedKeys',
            'defaultSelectedKeys',
            'checkedKeys',
            'defaultCheckedKeys',
            'halfCheckedKeys',
            'checkStrictly',
            'showLine',
            'switcherIcon',
            'height',
            'draggable',
            'showDragIcon',
            'dragInSameLevel',
            'dragDisabledKeys',
            'dropDisabledKeys',
            'draggedNodeKey',
            'clickedContextMenu',
            'enableNodeFavorites',
            'favoritedKeys',
            'scrollTarget',
            'searchKeyword',
            'caseSensitive',
            'highlightStyle',
            'nodeCheckedSuffix',
            'nodeUncheckedSuffix',
            'nodeCheckedStyle',
            'nodeUncheckedStyle',
            'enableAsyncLoad',
            'loadingNode',
            'batchPropsNames',
            'batchPropsValues',
            'data-*',
            'aria-*',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'treeDataMode',
            'treeData',
            'treeNodeKeyToTitle',
            'showIcon',
            'selectable',
            'multiple',
            'checkable',
            'defaultExpandAll',
            'expandedKeys',
            'defaultExpandedKeys',
            'defaultExpandParent',
            'selectedKeys',
            'defaultSelectedKeys',
            'checkedKeys',
            'defaultCheckedKeys',
            'halfCheckedKeys',
            'checkStrictly',
            'showLine',
            'switcherIcon',
            'height',
            'draggable',
            'showDragIcon',
            'dragInSameLevel',
            'dragDisabledKeys',
            'dropDisabledKeys',
            'draggedNodeKey',
            'clickedContextMenu',
            'enableNodeFavorites',
            'favoritedKeys',
            'scrollTarget',
            'searchKeyword',
            'caseSensitive',
            'highlightStyle',
            'nodeCheckedSuffix',
            'nodeUncheckedSuffix',
            'nodeCheckedStyle',
            'nodeUncheckedStyle',
            'enableAsyncLoad',
            'loadingNode',
            'batchPropsNames',
            'batchPropsValues',
            'data-*',
            'aria-*',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdTree, self).__init__(**args)


setattr(AntdTree, '__init__', _explicitize_args(AntdTree.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdDatePicker(Component):
    """An AntdDatePicker component.
    日期选择组件AntdDatePicker

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - popupClassName (string; optional):
        展开菜单css类名.

    - name (string; optional):
        配合`AntdForm`表单批量值搜集/控制功能使用，充当当前表单项的字段名，以`id`作为缺省值.

    - enableBatchControl (boolean; default True):
        控制当前组件是否参与有效的`AntdForm`表单批量值搜集/控制功能 默认值：`True`.

    - locale (a value equal to: 'zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr'; default 'zh-cn'):
        组件文案语种，可选项有`'zh-cn'`（简体中文）、`'en-us'`（英语）、`'de-de'`（德语）、`'fr-fr'`（法语）、`'ru-ru'`（俄语）
        默认值：`'zh-cn'`.

    - format (string; optional):
        日期时间显示格式，[参考资料](https://day.js.org/docs/en/display/format)
        默认值：`'YYYY-MM-DD'`.

    - picker (a value equal to: 'date', 'week', 'month', 'quarter', 'year'; default 'date'):
        日期选择粒度，可选项有`'date'`、`'week'`、`'month'`、`'quarter'`、`'year'`
        默认值：`'date'`.

    - firstDayOfWeek (number; optional):
        自定义每周起始日下标.

    - disabled (boolean; default False):
        是否禁用当前组件 默认值：`False`.

    - showTime (dict; default False):
        配置时间选择面板相关参数 默认值：`False`.

        `showTime` is a boolean | dict with keys:

        - defaultValue (string; optional):
            时间选择面板初始化选中时间字符串.

        - format (string; optional):
            与`defaultValue`对应的时间格式，[参考资料](https://day.js.org/docs/en/display/format)
            默认值：`'HH:mm:ss'`.

    - size (a value equal to: 'small', 'middle', 'large'; default 'middle'):
        当前组件尺寸规格，可选项有`'small'`、`'middle'`、`'large'` 默认值：`'middle'`.

    - bordered (boolean; default True):
        是否显示边框，设置为`True`时等价于`variant='outlined'` 默认值：`True`.

    - variant (a value equal to: 'outlined', 'borderless', 'filled', 'underlined'; optional):
        形态变体类型，可选项有`'outlined'`、`'borderless'`、`'filled'`、`'underlined'`，其中`'outlined'`等价于`bordered=True`，但优先级更高.

    - placeholder (string; optional):
        输入框占位文字内容.

    - placement (a value equal to: 'bottomLeft', 'bottomRight', 'topLeft', 'topRight'; default 'bottomLeft'):
        选择面板展开方向，可选项有`'bottomLeft'`、`'bottomRight'`、`'topLeft'`、`'topRight'`
        默认值：`'bottomLeft'`.

    - value (string; optional):
        监听或设置已选值，与`format`格式对应.

    - defaultValue (string; optional):
        初始化已选值，与`format`格式对应.

    - pickerValue (string; optional):
        监听或设置面板展开对应日期，与`format`格式对应.

    - disabledDatesStrategy (list of dicts; optional):
        配置日期禁用项策略数组，满足策略中至少一项规则的日期将会被禁止选中.

        `disabledDatesStrategy` is a list of dicts with keys:

        - mode (a value equal to: 'eq', 'ne', 'le', 'lt', 'ge', 'gt', 'in', 'not-in', 'in-enumerate-dates', 'not-in-enumerate-dates'; optional):
            当前策略类型，可选项有`'eq'`（等于）、`'ne'`（不等于）、`'le'`（小于等于）、`'lt'`（小于）、`'ge'`（大于等于）
            、`'gt'`（大于）、`'in'`（属于）、`'not-in'`（不属于）、`'in-enumerate-dates'`（属于日期字符串枚举数组），`'not-in-enumerate-dates'`（不属于日期字符串枚举数组）.

        - target (a value equal to: 'day', 'month', 'quarter', 'year', 'dayOfYear', 'dayOfWeek', 'specific-date'; optional):
            当前策略约束目标，可选项有`'dayOfYear'`（按年份天数）、`'dayOfWeek'`（按周天数）、`'day'`（按日）
            、`'month'`（按月份）、`'quarter'`（按季度）、`'year'`（按年份）、`'specific-date'`（具体日期）
            ，其中在`'specific-date'`目标下，`value`值将严格按照`'YYYY-MM-DD'`格式进行解析.

        - value (number | string | list of numbers | list of strings; optional):
            与策略类型、策略约束目标相对应的实际约束值.

    - status (a value equal to: 'error', 'warning'; optional):
        控制校验状态，可选项有`'error'`、`'warning'`.

    - allowClear (boolean; default True):
        是否允许一键清空已选值 默认值：`True`.

    - autoFocus (boolean; default False):
        是否自动获取焦点 默认值：`False`.

    - readOnly (boolean; optional):
        是否渲染为只读状态 默认值：`False`.

    - extraFooter (a list of or a singular dash component, string or number; optional):
        组件型，底部额外区域内容.

    - showToday (boolean; default True):
        是否显示“今天”快捷选择按钮 默认值：`True`.

    - presets (list of dicts; optional):
        配置预设项列表.

        `presets` is a list of dicts with keys:

        - label (a list of or a singular dash component, string or number; optional):
            组件型，当前预设项标题.

        - value (string; optional):
            当前预设项对应值，与`format`格式对应.

    - clickedPreset (dict; optional):
        配合`presets`参数，监听最近一次预设项点击事件相关信息.

        `clickedPreset` is a dict with keys:

        - value (string | number; optional):
            对应预设项值.

        - timestamp (number; optional):
            事件对应时间戳信息.

    - needConfirm (boolean; default False):
        是否需要点击按钮确认选值，传入`False`时失去焦点即代表选择 默认值：`False`.

    - customCells (list of dicts; optional):
        自定义对应日期的单元格样式.

        `customCells` is a list of dicts with keys:

        - year (number; optional):
            当前项匹配的年份值.

        - month (number; optional):
            当前项匹配的月份值.

        - date (number; optional):
            当前项匹配的日期值.

        - style (dict; optional):
            自定义css样式.

        - className (string; optional):
            自定义css类名.

    - prefix (a list of or a singular dash component, string or number; optional):
        组件型，前缀内嵌内容.

    - suffixIcon (a list of or a singular dash component, string or number; optional):
        自定义选择框后缀图标内容.

    - popupContainer (a value equal to: 'parent', 'body'; default 'body'):
        相关展开层锚定策略，可选项有`'parent'`、`'body'` 默认值：`'body'`.

    - batchPropsNames (list of strings; optional):
        需要纳入[批量属性监听](/batch-props-values)的若干属性名.

    - batchPropsValues (dict; optional):
        监听`batchPropsNames`中指定的若干属性值.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配.

    - persistence (boolean | string | number; optional):
        是否开启[属性持久化](/prop-persistence).

    - persisted_props (list of a value equal to: 'value's; optional):
        开启属性持久化功能的若干属性名，可选项有`'value'` 默认值：`['value']`.

    - persistence_type (a value equal to: 'local', 'session', 'memory'; optional):
        属性持久化存储类型，可选项有`'local'`（本地持久化），`'session'`（会话持久化），`'memory'`（内存持久化）
        默认值：`'local'`."""

    _children_props: typing.List[str] = ['extraFooter', 'presets[].label', 'prefix', 'suffixIcon']
    _base_nodes = ['extraFooter', 'prefix', 'suffixIcon', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdDatePicker'
    ShowTime = TypedDict('ShowTime', {'defaultValue': NotRequired[str], 'format': NotRequired[str]})

    DisabledDatesStrategy = TypedDict(
        'DisabledDatesStrategy',
        {
            'mode': NotRequired[
                Literal[
                    'eq',
                    'ne',
                    'le',
                    'lt',
                    'ge',
                    'gt',
                    'in',
                    'not-in',
                    'in-enumerate-dates',
                    'not-in-enumerate-dates',
                ]
            ],
            'target': NotRequired[
                Literal[
                    'day', 'month', 'quarter', 'year', 'dayOfYear', 'dayOfWeek', 'specific-date'
                ]
            ],
            'value': NotRequired[
                typing.Union[NumberType, str, typing.Sequence[NumberType], typing.Sequence[str]]
            ],
        },
    )

    Presets = TypedDict('Presets', {'label': NotRequired[ComponentType], 'value': NotRequired[str]})

    ClickedPreset = TypedDict(
        'ClickedPreset',
        {'value': NotRequired[typing.Union[str, NumberType]], 'timestamp': NotRequired[NumberType]},
    )

    CustomCells = TypedDict(
        'CustomCells',
        {
            'year': NotRequired[NumberType],
            'month': NotRequired[NumberType],
            'date': NotRequired[NumberType],
            'style': NotRequired[dict],
            'className': NotRequired[str],
        },
    )

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        popupClassName: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        enableBatchControl: typing.Optional[bool] = None,
        locale: typing.Optional[Literal['zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr']] = None,
        format: typing.Optional[str] = None,
        picker: typing.Optional[Literal['date', 'week', 'month', 'quarter', 'year']] = None,
        firstDayOfWeek: typing.Optional[NumberType] = None,
        disabled: typing.Optional[bool] = None,
        showTime: typing.Optional[typing.Union[bool, 'ShowTime']] = None,
        size: typing.Optional[Literal['small', 'middle', 'large']] = None,
        bordered: typing.Optional[bool] = None,
        variant: typing.Optional[Literal['outlined', 'borderless', 'filled', 'underlined']] = None,
        placeholder: typing.Optional[str] = None,
        placement: typing.Optional[
            Literal['bottomLeft', 'bottomRight', 'topLeft', 'topRight']
        ] = None,
        value: typing.Optional[str] = None,
        defaultValue: typing.Optional[str] = None,
        pickerValue: typing.Optional[str] = None,
        disabledDatesStrategy: typing.Optional[typing.Sequence['DisabledDatesStrategy']] = None,
        status: typing.Optional[Literal['error', 'warning']] = None,
        allowClear: typing.Optional[bool] = None,
        autoFocus: typing.Optional[bool] = None,
        readOnly: typing.Optional[bool] = None,
        extraFooter: typing.Optional[ComponentType] = None,
        showToday: typing.Optional[bool] = None,
        presets: typing.Optional[typing.Sequence['Presets']] = None,
        clickedPreset: typing.Optional['ClickedPreset'] = None,
        needConfirm: typing.Optional[bool] = None,
        customCells: typing.Optional[typing.Sequence['CustomCells']] = None,
        prefix: typing.Optional[ComponentType] = None,
        suffixIcon: typing.Optional[ComponentType] = None,
        popupContainer: typing.Optional[Literal['parent', 'body']] = None,
        batchPropsNames: typing.Optional[typing.Sequence[str]] = None,
        batchPropsValues: typing.Optional[dict] = None,
        persistence: typing.Optional[typing.Union[bool, str, NumberType]] = None,
        persisted_props: typing.Optional[typing.Sequence[Literal['value']]] = None,
        persistence_type: typing.Optional[Literal['local', 'session', 'memory']] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'popupClassName',
            'name',
            'enableBatchControl',
            'locale',
            'format',
            'picker',
            'firstDayOfWeek',
            'disabled',
            'showTime',
            'size',
            'bordered',
            'variant',
            'placeholder',
            'placement',
            'value',
            'defaultValue',
            'pickerValue',
            'disabledDatesStrategy',
            'status',
            'allowClear',
            'autoFocus',
            'readOnly',
            'extraFooter',
            'showToday',
            'presets',
            'clickedPreset',
            'needConfirm',
            'customCells',
            'prefix',
            'suffixIcon',
            'popupContainer',
            'batchPropsNames',
            'batchPropsValues',
            'data-*',
            'aria-*',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'popupClassName',
            'name',
            'enableBatchControl',
            'locale',
            'format',
            'picker',
            'firstDayOfWeek',
            'disabled',
            'showTime',
            'size',
            'bordered',
            'variant',
            'placeholder',
            'placement',
            'value',
            'defaultValue',
            'pickerValue',
            'disabledDatesStrategy',
            'status',
            'allowClear',
            'autoFocus',
            'readOnly',
            'extraFooter',
            'showToday',
            'presets',
            'clickedPreset',
            'needConfirm',
            'customCells',
            'prefix',
            'suffixIcon',
            'popupContainer',
            'batchPropsNames',
            'batchPropsValues',
            'data-*',
            'aria-*',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdDatePicker, self).__init__(**args)


setattr(AntdDatePicker, '__init__', _explicitize_args(AntdDatePicker.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdProgress(Component):
    """An AntdProgress component.
    进度条组件AntdProgress

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - type (a value equal to: 'line', 'circle', 'dashboard'; default 'line'):
        进度条类型，可选项有`'line'`、`'circle'`、`'dashboard'` 默认值：`'line'`.

    - size (dict; default 'default'):
        进度条尺寸规格，可选项有`'small'`、`'default'`、`'large'`，传入数值型表示像素尺寸，传入字典型可分别控制宽度和高度
        默认值：`'default'`.

        `size` is a number | list of number | strings | a value equal to:
        'small', 'default' | dict with keys:

        - width (number; optional):
            像素宽度.

        - height (number; optional):
            像素高度.

    - percent (number; default 0):
        进度条进度，取值应在`0`到`100`之间，当`100`时默认会渲染为完成状态 默认值：`0`.

    - success (dict; optional):
        配置进度条完成状态相关参数.

        `success` is a dict with keys:

        - percent (number; optional):
            达到完成状态对应的进度，取值应在`0`到`100`之间 默认值：`100`.

        - strokeColor (dict; optional):
            完成状态进度条颜色，支持渐变色.

            `strokeColor` is a string

          Or dict with keys:

            - from (string; optional):

                渐变色开端颜色.

            - to (string; optional):

                渐变色末端颜色.

    - format (dict; optional):
        配置进度提示相关参数.

        `format` is a dict with keys:

        - prefix (string; optional):
            进度提示前缀文字 默认值：`''`.

        - suffix (string; optional):
            进度提示后缀文字 默认值：`'%'`.

        - content (a list of or a singular dash component, string or number; optional):
            组件型，强制设置显示内容.

    - status (a value equal to: 'success', 'exception', 'normal', 'active'; optional):
        进度条状态，可选项有`'success'`、`'exception'`、`'normal'`、`'active'`，其中`'active'`仅在`type='line'`时生效
        默认值：`'normal'`.

    - showInfo (boolean; default True):
        是否显示进度数值或状态图标 默认值：`True`.

    - percentPosition (dict; optional):
        适用于`'line'`型进度条，配置进度条附带进度数值信息显示位置.

        `percentPosition` is a dict with keys:

        - align (a value equal to: 'start', 'center', 'end'; optional):
            对齐方式，可选项有`'start'`、`'center'`、`'end'`.

        - type (a value equal to: 'inner', 'outer'; optional):
            内外位置，可选项有`'inner'`、`'outer'`.

    - strokeColor (dict; optional):
        配置进度条颜色，支持渐变色.

        `strokeColor` is a string | list of strings | dict with keys:

        - from (string; optional):
            渐变色开端颜色.

        - to (string; optional):
            渐变色末端颜色. | dict with strings as keys and values of type string

    - strokeLinecap (a value equal to: 'round', 'butt', 'square'; optional):
        进度条线型，可选项有`'round'`、`'butt'`、`'square'` 默认值：`'round'`.

    - strokeWidth (number; optional):
        进度条线的宽度，单位是进度条画布宽度的百分比.

    - trailColor (string; optional):
        未完成分段部分的颜色，默认无颜色.

    - gapDegree (number; optional):
        进度条缺口角度，取值应在`0`到`295`之间，仅`type='dashboard'`时可用 默认值：`75`.

    - gapPosition (a value equal to: 'top', 'bottom', 'left', 'right'; default 'bottom'):
        仪表盘缺口方向，可选项有`'top'`、`'bottom'`、`'left'`、`'right'`，仅`type='dashboard'`时可用
        默认值：`'bottom'`.

    - steps (dict; optional):
        配置进度条分段数量，针对`'circle'`、`'dashboard'`型进度条支持传入字典型进行更详细的配置.

        `steps` is a number | dict with keys:

        - count (number; optional):
            分段数量.

        - gap (number; optional):
            分段间隔像素大小.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = ['format.content']
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdProgress'
    Size = TypedDict('Size', {'width': NotRequired[NumberType], 'height': NotRequired[NumberType]})

    SuccessStrokeColor = TypedDict(
        'SuccessStrokeColor', {'from': NotRequired[str], 'to': NotRequired[str]}
    )

    Success = TypedDict(
        'Success',
        {
            'percent': NotRequired[NumberType],
            'strokeColor': NotRequired[typing.Union[str, 'SuccessStrokeColor']],
        },
    )

    Format = TypedDict(
        'Format',
        {
            'prefix': NotRequired[str],
            'suffix': NotRequired[str],
            'content': NotRequired[ComponentType],
        },
    )

    PercentPosition = TypedDict(
        'PercentPosition',
        {
            'align': NotRequired[Literal['start', 'center', 'end']],
            'type': NotRequired[Literal['inner', 'outer']],
        },
    )

    StrokeColor = TypedDict('StrokeColor', {'from': NotRequired[str], 'to': NotRequired[str]})

    Steps = TypedDict('Steps', {'count': NotRequired[NumberType], 'gap': NotRequired[NumberType]})

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        type: typing.Optional[Literal['line', 'circle', 'dashboard']] = None,
        size: typing.Optional[
            typing.Union[
                NumberType,
                typing.Sequence[typing.Union[NumberType, str]],
                Literal['small', 'default'],
                'Size',
            ]
        ] = None,
        percent: typing.Optional[NumberType] = None,
        success: typing.Optional['Success'] = None,
        format: typing.Optional['Format'] = None,
        status: typing.Optional[Literal['success', 'exception', 'normal', 'active']] = None,
        showInfo: typing.Optional[bool] = None,
        percentPosition: typing.Optional['PercentPosition'] = None,
        strokeColor: typing.Optional[
            typing.Union[
                str,
                typing.Sequence[str],
                'StrokeColor',
                typing.Dict[typing.Union[str, float, int], str],
            ]
        ] = None,
        strokeLinecap: typing.Optional[Literal['round', 'butt', 'square']] = None,
        strokeWidth: typing.Optional[NumberType] = None,
        trailColor: typing.Optional[str] = None,
        gapDegree: typing.Optional[NumberType] = None,
        gapPosition: typing.Optional[Literal['top', 'bottom', 'left', 'right']] = None,
        steps: typing.Optional[typing.Union[NumberType, 'Steps']] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'type',
            'size',
            'percent',
            'success',
            'format',
            'status',
            'showInfo',
            'percentPosition',
            'strokeColor',
            'strokeLinecap',
            'strokeWidth',
            'trailColor',
            'gapDegree',
            'gapPosition',
            'steps',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'type',
            'size',
            'percent',
            'success',
            'format',
            'status',
            'showInfo',
            'percentPosition',
            'strokeColor',
            'strokeLinecap',
            'strokeWidth',
            'trailColor',
            'gapDegree',
            'gapPosition',
            'steps',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdProgress, self).__init__(**args)


setattr(AntdProgress, '__init__', _explicitize_args(AntdProgress.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdSteps(Component):
    """An AntdSteps component.
    步骤条组件AntdSteps

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - steps (list of dicts; required):
        必填，步骤内容定义数据结构.

        `steps` is a list of dicts with keys:

        - title (a list of or a singular dash component, string or number; required):
            步骤标题.

        - subTitle (a list of or a singular dash component, string or number; optional):
            步骤子标题.

        - description (a list of or a singular dash component, string or number; optional):
            步骤描述内容.

        - icon (a list of or a singular dash component, string or number; optional):
            步骤自定义图标.

        - disabled (boolean; optional):
            是否禁用当前步骤.

        - status (a value equal to: 'wait', 'process', 'finish', 'error'; optional):
            强制设置当前步骤状态，同参数status.

    - current (number; default 0):
        当前所处的步骤序号 默认值：`0`.

    - direction (a value equal to: 'horizontal', 'vertical'; default 'horizontal'):
        步骤条显示方向，可选项有`'horizontal'`、`'vertical'` 默认值：`'horizontal'`.

    - labelPlacement (a value equal to: 'horizontal', 'vertical'; optional):
        标签内容显示方位，可选项有`'horizontal'`、`'vertical'`.

    - progressDot (boolean; default False):
        是否渲染为点状步骤条 默认值：`False`.

    - size (a value equal to: 'default', 'small'; default 'default'):
        步骤条尺寸规格，可选项有`'default'`、`'small'` 默认值：`'default'`.

    - status (a value equal to: 'wait', 'process', 'finish', 'error'; default 'process'):
        步骤条状态，可选项有`'wait'`、`'process'`、`'finish'`、`'error'`
        默认值：`'process'`.

    - type (a value equal to: 'default', 'navigation', 'inline'; default 'default'):
        步骤条类型，可选项有`'default'`、`'navigation'`、`'inline'` 默认值：`'default'`.

    - allowClick (boolean; default False):
        是否可点击切换步骤 默认值：`False`.

    - responsive (boolean; default True):
        是否在页面宽度小于532px时自动强制垂直显示 默认值：`True`.

    - percent (number; optional):
        当前步骤进度，取值应在0到100之间，适用于常规步骤条.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = [
        'steps[].title',
        'steps[].subTitle',
        'steps[].description',
        'steps[].icon',
    ]
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdSteps'
    Steps = TypedDict(
        'Steps',
        {
            'title': ComponentType,
            'subTitle': NotRequired[ComponentType],
            'description': NotRequired[ComponentType],
            'icon': NotRequired[ComponentType],
            'disabled': NotRequired[bool],
            'status': NotRequired[Literal['wait', 'process', 'finish', 'error']],
        },
    )

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        steps: typing.Optional[typing.Sequence['Steps']] = None,
        current: typing.Optional[NumberType] = None,
        direction: typing.Optional[Literal['horizontal', 'vertical']] = None,
        labelPlacement: typing.Optional[Literal['horizontal', 'vertical']] = None,
        progressDot: typing.Optional[bool] = None,
        size: typing.Optional[Literal['default', 'small']] = None,
        status: typing.Optional[Literal['wait', 'process', 'finish', 'error']] = None,
        type: typing.Optional[Literal['default', 'navigation', 'inline']] = None,
        allowClick: typing.Optional[bool] = None,
        responsive: typing.Optional[bool] = None,
        percent: typing.Optional[NumberType] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'steps',
            'current',
            'direction',
            'labelPlacement',
            'progressDot',
            'size',
            'status',
            'type',
            'allowClick',
            'responsive',
            'percent',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'steps',
            'current',
            'direction',
            'labelPlacement',
            'progressDot',
            'size',
            'status',
            'type',
            'allowClick',
            'responsive',
            'percent',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['steps']:
            if k not in args:
                raise TypeError('Required argument `' + k + '` was not specified.')

        super(AntdSteps, self).__init__(**args)


setattr(AntdSteps, '__init__', _explicitize_args(AntdSteps.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdButton(Component):
    """An AntdButton component.
    按钮组件AntdButton

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - children (a list of or a singular dash component, string or number; optional):
        组件型，按钮内嵌元素.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - styles (dict; optional):
        细分控制子元素css样式.

        `styles` is a dict with keys:

        - icon (dict; optional):
            按钮图标元素css样式.

    - classNames (dict; optional):
        细分控制子元素css类名.

        `classNames` is a dict with keys:

        - icon (string; optional):
            按钮图标元素css类名.

    - loadingChildren (a list of or a singular dash component, string or number; optional):
        组件型，按钮加载状态下显示的内嵌元素.

    - type (a value equal to: 'default', 'primary', 'dashed', 'link', 'text'; default 'default'):
        按钮类型，可选项有`'default'`、`'primary'`、`'dashed'`、`'link'`、`'text'`
        默认值：`'default'`.

    - href (string; optional):
        按钮点击跳转链接地址.

    - target (string; default '_blank'):
        按钮点击跳转链接方式 默认值：`'_blank'`.

    - autoInsertSpace (boolean; default True):
        按钮两个汉字内是否插入空格 默认值：`True`.

    - block (boolean; default False):
        按钮是否渲染为块级元素（宽度撑满父容器） 默认值：`False`.

    - danger (boolean; default False):
        按钮是否呈现危险样式 默认值：`False`.

    - disabled (boolean; default False):
        按钮是否呈现禁用状态 默认值：`False`.

    - ghost (boolean; default False):
        按钮是否呈现透明背景状态 默认值：`False`.

    - shape (a value equal to: 'default', 'circle', 'round'; default 'default'):
        按钮形状，可选项有`'default'`、`'circle'`、`'round'` 默认值：`'default'`.

    - size (a value equal to: 'small', 'middle', 'large'; default 'middle'):
        按钮尺寸规格，可选项有`'small'`、`'middle'`、`'large'` 默认值：`'middle'`.

    - nClicks (number; default 0):
        按钮累计点击次数，用于监听按钮点击行为 默认值：`0`.

    - clickExecuteJsString (string; optional):
        按钮点击时需要附带执行的js程序字符串.

    - debounceWait (number; default 0):
        按钮点击事件监听防抖延时，单位：毫秒 默认值：`0`.

    - icon (a list of or a singular dash component, string or number; optional):
        组件型，按钮内嵌前缀图标元素.

    - iconPosition (a value equal to: 'start', 'end'; default 'start'):
        按钮图标组件的位置，可选项有`'start'`、`'end'` 默认值：`'start'`.

    - loading (boolean; optional):
        按钮是否呈现加载状态 默认值：`False`.

    - autoSpin (boolean; default False):
        当前按钮在每次点击后是否自动进入加载中状态 默认值：`False`.

    - motionType (a value equal to: 'happy-work'; optional):
        按钮额外的特殊交互类型，可选项有`'happy-work'`.

    - color (a value equal to: 'default', 'primary', 'danger', 'blue', 'purple', 'cyan', 'green', 'magenta', 'pink', 'red', 'orange', 'yellow', 'volcano', 'geekblue', 'lime', 'gold'; optional):
        按钮颜色风格，可选项有`'default'`、`'primary'`、`'danger'`，以及可用的一系列内置颜色：`'blue'`、`'purple'`、`'cyan'`、`'green'`、`'magenta'`、`'pink'`、`'red'`、`'orange'`、`'yellow'`、`'volcano'`、`'geekblue'`、`'lime'`、`'gold'`.

    - variant (a value equal to: 'outlined', 'dashed', 'solid', 'filled', 'text', 'link'; optional):
        形态变体类型，可选项有`'outlined'`、`'dashed'`、`'solid'`、`'filled'`、`'text'`、`'link'`.

    - title (string; optional):
        原生按钮title属性.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = ['loadingChildren', 'icon']
    _base_nodes = ['loadingChildren', 'icon', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdButton'
    Styles = TypedDict('Styles', {'icon': NotRequired[dict]})

    ClassNames = TypedDict('ClassNames', {'icon': NotRequired[str]})

    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        styles: typing.Optional['Styles'] = None,
        classNames: typing.Optional['ClassNames'] = None,
        loadingChildren: typing.Optional[ComponentType] = None,
        type: typing.Optional[Literal['default', 'primary', 'dashed', 'link', 'text']] = None,
        href: typing.Optional[str] = None,
        target: typing.Optional[str] = None,
        autoInsertSpace: typing.Optional[bool] = None,
        block: typing.Optional[bool] = None,
        danger: typing.Optional[bool] = None,
        disabled: typing.Optional[bool] = None,
        ghost: typing.Optional[bool] = None,
        shape: typing.Optional[Literal['default', 'circle', 'round']] = None,
        size: typing.Optional[Literal['small', 'middle', 'large']] = None,
        nClicks: typing.Optional[NumberType] = None,
        clickExecuteJsString: typing.Optional[str] = None,
        debounceWait: typing.Optional[NumberType] = None,
        icon: typing.Optional[ComponentType] = None,
        iconPosition: typing.Optional[Literal['start', 'end']] = None,
        loading: typing.Optional[bool] = None,
        autoSpin: typing.Optional[bool] = None,
        motionType: typing.Optional[Literal['happy-work']] = None,
        color: typing.Optional[
            Literal[
                'default',
                'primary',
                'danger',
                'blue',
                'purple',
                'cyan',
                'green',
                'magenta',
                'pink',
                'red',
                'orange',
                'yellow',
                'volcano',
                'geekblue',
                'lime',
                'gold',
            ]
        ] = None,
        variant: typing.Optional[
            Literal['outlined', 'dashed', 'solid', 'filled', 'text', 'link']
        ] = None,
        title: typing.Optional[str] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'styles',
            'classNames',
            'loadingChildren',
            'type',
            'href',
            'target',
            'autoInsertSpace',
            'block',
            'danger',
            'disabled',
            'ghost',
            'shape',
            'size',
            'nClicks',
            'clickExecuteJsString',
            'debounceWait',
            'icon',
            'iconPosition',
            'loading',
            'autoSpin',
            'motionType',
            'color',
            'variant',
            'title',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'styles',
            'classNames',
            'loadingChildren',
            'type',
            'href',
            'target',
            'autoInsertSpace',
            'block',
            'danger',
            'disabled',
            'ghost',
            'shape',
            'size',
            'nClicks',
            'clickExecuteJsString',
            'debounceWait',
            'icon',
            'iconPosition',
            'loading',
            'autoSpin',
            'motionType',
            'color',
            'variant',
            'title',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdButton, self).__init__(children=children, **args)


setattr(AntdButton, '__init__', _explicitize_args(AntdButton.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdTag(Component):
    """An AntdTag component.
    标签组件AntdTag

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - content (a list of or a singular dash component, string or number; optional):
        组件型，标签内容.

    - icon (a list of or a singular dash component, string or number; optional):
        组件型，标签前缀图标.

    - color (string; optional):
        标签颜色，可使用内置的若干种颜色主题，也可使用任何合法的css颜色值.

    - href (string; optional):
        标签点击跳转链接地址.

    - target (string; default '_blank'):
        标签链接跳转行为.

    - bordered (boolean; default True):
        是否渲染边框 默认值：`True`.

    - closeIcon (boolean; default False):
        是否渲染关闭按钮 默认值：`False`.

    - closeCounts (number; default 0):
        `closeIcon=True`时，监听关闭按钮累计点击次数 默认值：`0`.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = ['content', 'icon']
    _base_nodes = ['content', 'icon', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdTag'

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        content: typing.Optional[ComponentType] = None,
        icon: typing.Optional[ComponentType] = None,
        color: typing.Optional[str] = None,
        href: typing.Optional[str] = None,
        target: typing.Optional[str] = None,
        bordered: typing.Optional[bool] = None,
        closeIcon: typing.Optional[bool] = None,
        closeCounts: typing.Optional[NumberType] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'content',
            'icon',
            'color',
            'href',
            'target',
            'bordered',
            'closeIcon',
            'closeCounts',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'content',
            'icon',
            'color',
            'href',
            'target',
            'bordered',
            'closeIcon',
            'closeCounts',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdTag, self).__init__(**args)


setattr(AntdTag, '__init__', _explicitize_args(AntdTag.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdTour(Component):
    """An AntdTour component.
    漫游式引导组件AntdTour

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - locale (a value equal to: 'zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr'; default 'zh-cn'):
        组件文案语种，可选项有`'zh-cn'`（简体中文）、`'en-us'`（英语）、`'de-de'`（德语）、`'fr-fr'`（法语）、`'ru-ru'`（俄语）
        默认值：`'zh-cn'`.

    - steps (list of dicts; optional):
        配置引导步骤.

        `steps` is a list of dicts with keys:

        - targetId (string; optional):
            当前步骤目标元素id，优先级高于`targetSelector`.

        - targetSelector (string; optional):
            定位当前步骤目标元素的javascript代码字符串.

        - arrow (dict; optional):
            配置当前步骤箭头 默认值：`True`.

            `arrow` is a boolean

          Or dict with keys:

            - pointAtCenter (boolean; optional):

                箭头是否指向目标中心.

        - cover (a list of or a singular dash component, string or number; optional):
            组件型，当前步骤弹框的封面内容.

        - title (a list of or a singular dash component, string or number; optional):
            组件型，当前步骤弹框的标题内容.

        - description (a list of or a singular dash component, string or number; optional):
            组件型，当前步骤弹框的描述内容.

        - placement (a value equal to: 'center', 'left', 'leftTop', 'leftBottom', 'right', 'rightTop', 'rightBottom', 'top', 'topLeft', 'topRight', 'bottom', 'bottomLeft', 'bottomRight'; optional):
            当前引导步骤弹框相对目标元素的位置，可选项有`'center'`、`'left'`、`'leftTop'`、`'leftBottom'`、`'right'`、`'rightTop'`、`'rightBottom'`、`'top'`、`'topLeft'`、`'topRight'`、`'bottom'`、`'bottomLeft'`、`'bottomRight'`.

        - mask (dict; optional):
            配置当前步骤蒙版层 默认值：`True`.

            `mask` is a boolean | dict with keys:

            - style (dict; optional):

                当前步骤蒙版层css样式.

            - color (string; optional):

                当前步骤蒙版层颜色.

        - type (a value equal to: 'default', 'primary'; optional):
            当前步骤弹框类型，可选项有`'default'`、`'primary'` 默认值：`'default'`.

        - nextButtonProps (dict; optional):
            配置当前步骤下一步按钮.

            `nextButtonProps` is a dict with keys:

            - children (a list of or a singular dash component, string or number; optional):
                组件型，按钮内嵌元素.

        - prevButtonProps (dict; optional):
            配置当前步骤上一步按钮.

            `prevButtonProps` is a dict with keys:

            - children (a list of or a singular dash component, string or number; optional):
                组件型，按钮内嵌元素.

    - arrow (dict; default True):
        统一配置引导步骤弹框箭头 默认值：`True`.

        `arrow` is a boolean | dict with keys:

        - pointAtCenter (boolean; optional):
            箭头是否指向目标中心.

    - placement (a value equal to: 'center', 'left', 'leftTop', 'leftBottom', 'right', 'rightTop', 'rightBottom', 'top', 'topLeft', 'topRight', 'bottom', 'bottomLeft', 'bottomRight'; default 'bottom'):
        统一配置引导步骤弹框相对于目标元素的展开方向，可选项有`'center'`、`'left'`、`'leftTop'`、`'leftBottom'`、`'right'`、`'rightTop'`、`'rightBottom'`、`'top'`、`'topLeft'`、`'topRight'`、`'bottom'`、`'bottomLeft'`、`'bottomRight'`
        默认值：`'bottom'`.

    - mask (dict; default True):
        统一配置引导弹框蒙版 默认值：`True`.

        `mask` is a boolean | dict with keys:

        - style (dict; optional):
            蒙版层css样式.

        - color (string; optional):
            蒙版层颜色.

    - type (a value equal to: 'default', 'primary'; default 'default'):
        统一设置引导步骤弹框类型，可选项有`'default'`、`'primary'` 默认值：`'default'`.

    - open (boolean; default False):
        监听或设置当前漫游式引导的打开状态 默认值：`False`.

    - current (number; optional):
        监听或设置当前漫游式引导所在步骤序号.

    - zIndex (number; default 1001):
        当前漫游式引导z-index 默认值：`1001`.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = [
        'steps[].cover',
        'steps[].title',
        'steps[].description',
        'steps[].nextButtonProps.children',
        'steps[].prevButtonProps.children',
    ]
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdTour'
    StepsArrow = TypedDict('StepsArrow', {'pointAtCenter': NotRequired[bool]})

    StepsMask = TypedDict('StepsMask', {'style': NotRequired[dict], 'color': NotRequired[str]})

    StepsNextButtonProps = TypedDict(
        'StepsNextButtonProps', {'children': NotRequired[ComponentType]}
    )

    StepsPrevButtonProps = TypedDict(
        'StepsPrevButtonProps', {'children': NotRequired[ComponentType]}
    )

    Steps = TypedDict(
        'Steps',
        {
            'targetId': NotRequired[str],
            'targetSelector': NotRequired[str],
            'arrow': NotRequired[typing.Union[bool, 'StepsArrow']],
            'cover': NotRequired[ComponentType],
            'title': NotRequired[ComponentType],
            'description': NotRequired[ComponentType],
            'placement': NotRequired[
                Literal[
                    'center',
                    'left',
                    'leftTop',
                    'leftBottom',
                    'right',
                    'rightTop',
                    'rightBottom',
                    'top',
                    'topLeft',
                    'topRight',
                    'bottom',
                    'bottomLeft',
                    'bottomRight',
                ]
            ],
            'mask': NotRequired[typing.Union[bool, 'StepsMask']],
            'type': NotRequired[Literal['default', 'primary']],
            'nextButtonProps': NotRequired['StepsNextButtonProps'],
            'prevButtonProps': NotRequired['StepsPrevButtonProps'],
        },
    )

    Arrow = TypedDict('Arrow', {'pointAtCenter': NotRequired[bool]})

    Mask = TypedDict('Mask', {'style': NotRequired[dict], 'color': NotRequired[str]})

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        locale: typing.Optional[Literal['zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr']] = None,
        steps: typing.Optional[typing.Sequence['Steps']] = None,
        arrow: typing.Optional[typing.Union[bool, 'Arrow']] = None,
        placement: typing.Optional[
            Literal[
                'center',
                'left',
                'leftTop',
                'leftBottom',
                'right',
                'rightTop',
                'rightBottom',
                'top',
                'topLeft',
                'topRight',
                'bottom',
                'bottomLeft',
                'bottomRight',
            ]
        ] = None,
        mask: typing.Optional[typing.Union[bool, 'Mask']] = None,
        type: typing.Optional[Literal['default', 'primary']] = None,
        open: typing.Optional[bool] = None,
        current: typing.Optional[NumberType] = None,
        zIndex: typing.Optional[NumberType] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'locale',
            'steps',
            'arrow',
            'placement',
            'mask',
            'type',
            'open',
            'current',
            'zIndex',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'locale',
            'steps',
            'arrow',
            'placement',
            'mask',
            'type',
            'open',
            'current',
            'zIndex',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdTour, self).__init__(**args)


setattr(AntdTour, '__init__', _explicitize_args(AntdTour.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdIcon(Component):
    """An AntdIcon component.
    图标组件AntdIcon

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - mode (a value equal to: 'default', 'iconfont'; default 'default'):
        图标调用模式，可选项有`'default'`（内置图标）、`'iconfont'`（阿里巴巴矢量图标）
        默认值：`'default'`.

    - icon (string; optional):
        当`mode='default'`时，设置内置图标名称，当`mode='iconfont'`时，设置自定义源图标名称.

    - scriptUrl (string | list of strings; optional):
        当`mode='iconfont'`时，设置单个或多个阿里巴巴矢量图标源（在iconfont.cn上制作）.

    - nClicks (number; default 0):
        图标累计点击次数，用于监听图标点击行为 默认值：`0`.

    - debounceWait (number; default 0):
        图标点击事件监听防抖延时，单位：毫秒 默认值：`0`.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdIcon'

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        mode: typing.Optional[Literal['default', 'iconfont']] = None,
        icon: typing.Optional[str] = None,
        scriptUrl: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        nClicks: typing.Optional[NumberType] = None,
        debounceWait: typing.Optional[NumberType] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'mode',
            'icon',
            'scriptUrl',
            'nClicks',
            'debounceWait',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'mode',
            'icon',
            'scriptUrl',
            'nClicks',
            'debounceWait',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdIcon, self).__init__(**args)


setattr(AntdIcon, '__init__', _explicitize_args(AntdIcon.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdRadioGroup(Component):
    """An AntdRadioGroup component.
    单选框组件AntdRadioGroup

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - name (string; optional):
        配合`AntdForm`表单批量值搜集/控制功能使用，充当当前表单项的字段名，以`id`作为缺省值.

    - enableBatchControl (boolean; default True):
        控制当前组件是否参与有效的`AntdForm`表单批量值搜集/控制功能 默认值：`True`.

    - direction (a value equal to: 'horizontal', 'vertical'; default 'horizontal'):
        单选框排列方向，可选项有`'horizontal'`、`'vertical'` 默认值：`'horizontal'`.

    - options (list of dicts; optional):
        配置选项.

        `options` is a list of string | number | dict with keys:

        - label (a list of or a singular dash component, string or number; optional):
            组件型，当前选项标签内容.

        - value (string | number; optional):
            当前选项值.

        - disabled (boolean; optional):
            是否禁用当前选项 默认值：`False`.s

    - block (boolean; default False):
        是否撑满父容器 默认值：`False`.

    - disabled (boolean; default False):
        是否禁用当前组件 默认值：`False`.

    - size (a value equal to: 'small', 'middle', 'large'; default 'middle'):
        当`optionType='button'`时，控制各选项按钮尺寸规格，可选项有`'small'`、`'middle'`、`'large'`
        默认值：`'middle'`.

    - value (string | number; optional):
        监听或设置已选值，与`format`格式对应.

    - defaultValue (string | number; optional):
        初始化已选值，与`format`格式对应.

    - optionType (a value equal to: 'default', 'button'; default 'default'):
        选项形式，可选项有`'default'`、`'button'` 默认值：`'default'`.

    - buttonStyle (a value equal to: 'outline', 'solid'; default 'outline'):
        当`optionType='button'`时，设置按钮风格，可选项有`'outline'`、`'solid'`
        默认值：`'outline'`.

    - readOnly (boolean; default False):
        是否渲染为只读状态 默认值：`False`.

    - batchPropsNames (list of strings; optional):
        需要纳入[批量属性监听](/batch-props-values)的若干属性名.

    - batchPropsValues (dict; optional):
        监听`batchPropsNames`中指定的若干属性值.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配.

    - persistence (boolean | string | number; optional):
        是否开启[属性持久化](/prop-persistence).

    - persisted_props (list of a value equal to: 'value's; optional):
        开启属性持久化功能的若干属性名，可选项有`'value'` 默认值：`['value']`.

    - persistence_type (a value equal to: 'local', 'session', 'memory'; optional):
        属性持久化存储类型，可选项有`'local'`（本地持久化），`'session'`（会话持久化），`'memory'`（内存持久化）
        默认值：`'local'`."""

    _children_props: typing.List[str] = ['options[].label']
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdRadioGroup'
    Options = TypedDict(
        'Options',
        {
            'label': NotRequired[ComponentType],
            'value': NotRequired[typing.Union[str, NumberType]],
            'disabled': NotRequired[bool],
        },
    )

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        name: typing.Optional[str] = None,
        enableBatchControl: typing.Optional[bool] = None,
        direction: typing.Optional[Literal['horizontal', 'vertical']] = None,
        options: typing.Optional[typing.Sequence[typing.Union[str, NumberType, 'Options']]] = None,
        block: typing.Optional[bool] = None,
        disabled: typing.Optional[bool] = None,
        size: typing.Optional[Literal['small', 'middle', 'large']] = None,
        value: typing.Optional[typing.Union[str, NumberType]] = None,
        defaultValue: typing.Optional[typing.Union[str, NumberType]] = None,
        optionType: typing.Optional[Literal['default', 'button']] = None,
        buttonStyle: typing.Optional[Literal['outline', 'solid']] = None,
        readOnly: typing.Optional[bool] = None,
        batchPropsNames: typing.Optional[typing.Sequence[str]] = None,
        batchPropsValues: typing.Optional[dict] = None,
        persistence: typing.Optional[typing.Union[bool, str, NumberType]] = None,
        persisted_props: typing.Optional[typing.Sequence[Literal['value']]] = None,
        persistence_type: typing.Optional[Literal['local', 'session', 'memory']] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'name',
            'enableBatchControl',
            'direction',
            'options',
            'block',
            'disabled',
            'size',
            'value',
            'defaultValue',
            'optionType',
            'buttonStyle',
            'readOnly',
            'batchPropsNames',
            'batchPropsValues',
            'data-*',
            'aria-*',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'name',
            'enableBatchControl',
            'direction',
            'options',
            'block',
            'disabled',
            'size',
            'value',
            'defaultValue',
            'optionType',
            'buttonStyle',
            'readOnly',
            'batchPropsNames',
            'batchPropsValues',
            'data-*',
            'aria-*',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdRadioGroup, self).__init__(**args)


setattr(AntdRadioGroup, '__init__', _explicitize_args(AntdRadioGroup.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdTransfer(Component):
    """An AntdTransfer component.
    穿梭框组件AntdTransfer

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - name (string; optional):
        配合`AntdForm`表单批量值搜集/控制功能使用，充当当前表单项的字段名，以`id`作为缺省值.

    - enableBatchControl (boolean; default True):
        控制当前组件是否参与有效的`AntdForm`表单批量值搜集/控制功能 默认值：`True`.

    - locale (a value equal to: 'zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr'; default 'zh-cn'):
        组件文案语种，可选项有`'zh-cn'`（简体中文）、`'en-us'`（英语）、`'de-de'`（德语）、`'fr-fr'`（法语）、`'ru-ru'`（俄语）
        默认值：`'zh-cn'`.

    - dataSource (list of dicts; optional):
        配置选项.

        `dataSource` is a list of dicts with keys:

        - key (string | number; optional):
            当前选项唯一识别id.

        - title (a list of or a singular dash component, string or number; optional):
            组件型，当前选项标题内容.

        - disabled (boolean; optional):
            是否禁用当前选项 默认值：`False`.

    - selectionsIcon (a list of or a singular dash component, string or number; optional):
        组件型，自定义下拉菜单图标.

    - height (string | number; optional):
        穿梭框整体高度.

    - pagination (dict; default False):
        选项分页展示配置 默认值：`False`.

        `pagination` is a boolean | dict with keys:

        - pageSize (number; optional):
            每页最大选项数.

    - oneWay (boolean; default False):
        是否启用单向模式 默认值：`False`.

    - operations (list of a list of or a singular dash component, string or numbers; default ['', '']):
        左右移动操作按钮内容 默认值：`'['', '']'`.

    - showSearch (boolean; default False):
        是否显示搜索框 默认值：`False`.

    - optionFilterMode (a value equal to: 'case-insensitive', 'case-sensitive', 'regex'; default 'case-insensitive'):
        搜索匹配模式，可选项有`'case-insensitive'`（大小写不敏感）、`'case-sensitive'`（大小写敏感）、`'regex'`（正则表达式）
        默认值：`'case-insensitive'`.

    - showSelectAll (boolean; default True):
        是否显示全选勾选框 默认值：`True`.

    - titles (list of a list of or a singular dash component, string or numbers; optional):
        左右标题内容.

    - targetKeys (list of number | strings; optional):
        监听或设置右侧区域已选项`key`值.

    - moveDirection (a value equal to: 'left', 'right'; optional):
        监听最近一次选项移动对应方向，可选项有`'left'`、`'right'`.

    - moveKeys (list of number | strings; optional):
        监听最近一次选项移动涉及的选项`key`值.

    - disabled (boolean; default False):
        是否禁用当前组件 默认值：`False`.

    - status (a value equal to: 'error', 'warning'; optional):
        控制校验状态，可选项有`'error'`、`'warning'`.

    - readOnly (boolean; default False):
        是否渲染为只读状态 默认值：`False`.

    - batchPropsNames (list of strings; optional):
        需要纳入[批量属性监听](/batch-props-values)的若干属性名.

    - batchPropsValues (dict; optional):
        监听`batchPropsNames`中指定的若干属性值.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配.

    - loading_state (dict; optional)

        `loading_state` is a dict with keys:

        - is_loading (boolean; optional):
            Determines if the component is loading or not.

        - prop_name (string; optional):
            Holds which property is loading.

        - component_name (string; optional):
            Holds the name of the component that is loading.

    - persistence (boolean | string | number; optional):
        是否开启[属性持久化](/prop-persistence).

    - persisted_props (list of a value equal to: 'targetKeys's; optional):
        开启属性持久化功能的若干属性名，可选项有`'targetKeys'` 默认值：`['targetKeys']`.

    - persistence_type (a value equal to: 'local', 'session', 'memory'; optional):
        属性持久化存储类型，可选项有`'local'`（本地持久化），`'session'`（会话持久化），`'memory'`（内存持久化）
        默认值：`'local'`."""

    _children_props: typing.List[str] = [
        'dataSource[].title',
        'selectionsIcon',
        'operations',
        'titles',
    ]
    _base_nodes = ['selectionsIcon', 'operations', 'titles', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdTransfer'
    DataSource = TypedDict(
        'DataSource',
        {
            'key': NotRequired[typing.Union[str, NumberType]],
            'title': NotRequired[ComponentType],
            'disabled': NotRequired[bool],
        },
    )

    Pagination = TypedDict('Pagination', {'pageSize': NotRequired[NumberType]})

    LoadingState = TypedDict(
        'LoadingState',
        {
            'is_loading': NotRequired[bool],
            'prop_name': NotRequired[str],
            'component_name': NotRequired[str],
        },
    )

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        name: typing.Optional[str] = None,
        enableBatchControl: typing.Optional[bool] = None,
        locale: typing.Optional[Literal['zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr']] = None,
        dataSource: typing.Optional[typing.Sequence['DataSource']] = None,
        selectionsIcon: typing.Optional[ComponentType] = None,
        height: typing.Optional[typing.Union[str, NumberType]] = None,
        pagination: typing.Optional[typing.Union[bool, 'Pagination']] = None,
        oneWay: typing.Optional[bool] = None,
        operations: typing.Optional[typing.Sequence[ComponentType]] = None,
        showSearch: typing.Optional[bool] = None,
        optionFilterMode: typing.Optional[
            Literal['case-insensitive', 'case-sensitive', 'regex']
        ] = None,
        showSelectAll: typing.Optional[bool] = None,
        titles: typing.Optional[typing.Sequence[ComponentType]] = None,
        targetKeys: typing.Optional[typing.Sequence[typing.Union[NumberType, str]]] = None,
        moveDirection: typing.Optional[Literal['left', 'right']] = None,
        moveKeys: typing.Optional[typing.Sequence[typing.Union[NumberType, str]]] = None,
        disabled: typing.Optional[bool] = None,
        status: typing.Optional[Literal['error', 'warning']] = None,
        readOnly: typing.Optional[bool] = None,
        batchPropsNames: typing.Optional[typing.Sequence[str]] = None,
        batchPropsValues: typing.Optional[dict] = None,
        loading_state: typing.Optional['LoadingState'] = None,
        persistence: typing.Optional[typing.Union[bool, str, NumberType]] = None,
        persisted_props: typing.Optional[typing.Sequence[Literal['targetKeys']]] = None,
        persistence_type: typing.Optional[Literal['local', 'session', 'memory']] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'name',
            'enableBatchControl',
            'locale',
            'dataSource',
            'selectionsIcon',
            'height',
            'pagination',
            'oneWay',
            'operations',
            'showSearch',
            'optionFilterMode',
            'showSelectAll',
            'titles',
            'targetKeys',
            'moveDirection',
            'moveKeys',
            'disabled',
            'status',
            'readOnly',
            'batchPropsNames',
            'batchPropsValues',
            'data-*',
            'aria-*',
            'loading_state',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'name',
            'enableBatchControl',
            'locale',
            'dataSource',
            'selectionsIcon',
            'height',
            'pagination',
            'oneWay',
            'operations',
            'showSearch',
            'optionFilterMode',
            'showSelectAll',
            'titles',
            'targetKeys',
            'moveDirection',
            'moveKeys',
            'disabled',
            'status',
            'readOnly',
            'batchPropsNames',
            'batchPropsValues',
            'data-*',
            'aria-*',
            'loading_state',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdTransfer, self).__init__(**args)


setattr(AntdTransfer, '__init__', _explicitize_args(AntdTransfer.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdSlider(Component):
    """An AntdSlider component.
    滑动输入条组件AntdSlider

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - styles (dict; optional):
        细分控制子元素css样式.

        `styles` is a dict with keys:

        - root (dict; optional):
            根元素css样式.

        - track (dict; optional):
            范围选择下，点和点之间单个选取条css样式.

        - tracks (dict; optional):
            范围选择下，整个范围选取条css样式.

        - rail (dict; optional):
            背景条css样式.

        - handle (dict; optional):
            抓取点元素css样式.

    - classNames (dict; optional):
        细分控制子元素css类名.

        `classNames` is a dict with keys:

        - root (string; optional):
            根元素css类名.

        - track (string; optional):
            范围选择下，点和点之间单个选取条css类名.

        - tracks (string; optional):
            范围选择下，整个范围选取条css类名.

        - rail (string; optional):
            背景条css类名.

        - handle (string; optional):
            抓取点元素css类名.

    - name (string; optional):
        配合`AntdForm`表单批量值搜集/控制功能使用，充当当前表单项的字段名，以`id`作为缺省值.

    - enableBatchControl (boolean; default True):
        控制当前组件是否参与有效的`AntdForm`表单批量值搜集/控制功能 默认值：`True`.

    - vertical (boolean; default False):
        是否以垂直模式显示 默认值：`False`.

    - range (dict; default False):
        是否以范围模式显示.

        `range` is a boolean | dict with keys:

        - editable (boolean; optional):
            是否开启节点动态增减功能 默认值：`False`.

        - minCount (number; optional):
            开启节点动态增减功能后，允许的最小节点数量 默认值：`0`.

        - maxCount (number; optional):
            开启节点动态增减功能后，允许的最大节点数量.

    - min (number; default 0):
        必填，可滑动范围下限.

    - max (number; default 100):
        必填，可滑动范围上限.

    - step (number; default 1):
        滑动步长.

    - marks (dict with strings as keys and values of type a list of or a singular dash component, string or number; optional):
        为部分数值设置刻度信息.

    - tooltipVisible (boolean; optional):
        滑动数值文字提示显示策略，`True`表示持续显示，`False`表示始终不显示.

    - tooltipPrefix (string; default ''):
        滑动数值文字提示前缀信息.

    - tooltipSuffix (string; default ''):
        滑动数值文字提示后缀信息.

    - disabled (boolean; default False):
        是否禁用当前组件 默认值：`False`.

    - value (number | list of numbers; optional):
        监听或设置已选值.

    - defaultValue (number | list of numbers; optional):
        初始化已选值.

    - autoFocus (boolean; default False):
        是否允许一键清空已选值 默认值：`True`.

    - popupContainer (a value equal to: 'parent', 'body'; default 'body'):
        相关展开层锚定策略，可选项有`'parent'`、`'body'` 默认值：`'body'`.

    - readOnly (boolean; default False):
        是否渲染为只读状态 默认值：`False`.

    - batchPropsNames (list of strings; optional):
        需要纳入[批量属性监听](/batch-props-values)的若干属性名.

    - batchPropsValues (dict; optional):
        监听`batchPropsNames`中指定的若干属性值.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配.

    - persistence (boolean | string | number; optional):
        是否开启[属性持久化](/prop-persistence).

    - persisted_props (list of a value equal to: 'value's; optional):
        开启属性持久化功能的若干属性名，可选项有`'value'` 默认值：`['value']`.

    - persistence_type (a value equal to: 'local', 'session', 'memory'; optional):
        属性持久化存储类型，可选项有`'local'`（本地持久化），`'session'`（会话持久化），`'memory'`（内存持久化）
        默认值：`'local'`."""

    _children_props: typing.List[str] = ['marks{}']
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdSlider'
    Styles = TypedDict(
        'Styles',
        {
            'root': NotRequired[dict],
            'track': NotRequired[dict],
            'tracks': NotRequired[dict],
            'rail': NotRequired[dict],
            'handle': NotRequired[dict],
        },
    )

    ClassNames = TypedDict(
        'ClassNames',
        {
            'root': NotRequired[str],
            'track': NotRequired[str],
            'tracks': NotRequired[str],
            'rail': NotRequired[str],
            'handle': NotRequired[str],
        },
    )

    Range = TypedDict(
        'Range',
        {
            'editable': NotRequired[bool],
            'minCount': NotRequired[NumberType],
            'maxCount': NotRequired[NumberType],
        },
    )

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        styles: typing.Optional['Styles'] = None,
        classNames: typing.Optional['ClassNames'] = None,
        name: typing.Optional[str] = None,
        enableBatchControl: typing.Optional[bool] = None,
        vertical: typing.Optional[bool] = None,
        range: typing.Optional[typing.Union[bool, 'Range']] = None,
        min: typing.Optional[NumberType] = None,
        max: typing.Optional[NumberType] = None,
        step: typing.Optional[NumberType] = None,
        marks: typing.Optional[typing.Dict[typing.Union[str, float, int], ComponentType]] = None,
        tooltipVisible: typing.Optional[bool] = None,
        tooltipPrefix: typing.Optional[str] = None,
        tooltipSuffix: typing.Optional[str] = None,
        disabled: typing.Optional[bool] = None,
        value: typing.Optional[typing.Union[NumberType, typing.Sequence[NumberType]]] = None,
        defaultValue: typing.Optional[typing.Union[NumberType, typing.Sequence[NumberType]]] = None,
        autoFocus: typing.Optional[bool] = None,
        popupContainer: typing.Optional[Literal['parent', 'body']] = None,
        readOnly: typing.Optional[bool] = None,
        batchPropsNames: typing.Optional[typing.Sequence[str]] = None,
        batchPropsValues: typing.Optional[dict] = None,
        persistence: typing.Optional[typing.Union[bool, str, NumberType]] = None,
        persisted_props: typing.Optional[typing.Sequence[Literal['value']]] = None,
        persistence_type: typing.Optional[Literal['local', 'session', 'memory']] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'styles',
            'classNames',
            'name',
            'enableBatchControl',
            'vertical',
            'range',
            'min',
            'max',
            'step',
            'marks',
            'tooltipVisible',
            'tooltipPrefix',
            'tooltipSuffix',
            'disabled',
            'value',
            'defaultValue',
            'autoFocus',
            'popupContainer',
            'readOnly',
            'batchPropsNames',
            'batchPropsValues',
            'data-*',
            'aria-*',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'styles',
            'classNames',
            'name',
            'enableBatchControl',
            'vertical',
            'range',
            'min',
            'max',
            'step',
            'marks',
            'tooltipVisible',
            'tooltipPrefix',
            'tooltipSuffix',
            'disabled',
            'value',
            'defaultValue',
            'autoFocus',
            'popupContainer',
            'readOnly',
            'batchPropsNames',
            'batchPropsValues',
            'data-*',
            'aria-*',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdSlider, self).__init__(**args)


setattr(AntdSlider, '__init__', _explicitize_args(AntdSlider.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdQRCode(Component):
    """An AntdQRCode component.
    二维码组件AntdQRCode

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - locale (a value equal to: 'zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr'; default 'zh-cn'):
        组件文案语种，可选项有`'zh-cn'`（简体中文）、`'en-us'`（英语）、`'de-de'`（德语）、`'fr-fr'`（法语）、`'ru-ru'`（俄语）
        默认值：`'zh-cn'`.

    - value (string; optional):
        二维码解析结果.

    - type (a value equal to: 'canvas', 'svg'; default 'canvas'):
        渲染方式，可选项有`'canvas'`、`'svg'` 默认值：`'canvas'`.

    - icon (string; optional):
        二维码内嵌图片地址.

    - size (number; default 160):
        二维码像素边长 默认值：`160`.

    - iconSize (dict; default 40):
        二维码内嵌图片像素边长 默认值：`40`.

        `iconSize` is a number | dict with keys:

        - width (number; optional)

        - height (number; optional)

    - color (string; default '#000'):
        二维码颜色 默认值：`'#000'`.

    - bgColor (string; default 'transparent'):
        二维码背景颜色 默认值：`'transparent'`.

    - bordered (boolean; default True):
        二维码是否渲染边框 默认值：`True`.

    - errorLevel (a value equal to: 'L', 'M', 'Q', 'H'; default 'M'):
        二维码纠错级别，可选项有`'L'`、`'M'`、`'Q'`、`'H'` 默认值：`'M'`.

    - status (a value equal to: 'active', 'expired', 'loading', 'scanned'; default 'active'):
        二维码状态，可选项有`'active'`、`'expired'`、`'loading'`、`'scanned'`
        默认值：`'active'`.

    - expires (number; optional):
        当前二维码过期时间，单位：秒，到期后二维码状态将会被强制更新为`'expired'`.

    - autoSpin (boolean; default False):
        是否在`value`处于回调更新中时，自动切换为`loading`状态 默认值：`False`.

    - refreshClicks (number; default 0):
        监听当前\"点击刷新\"按钮累计点击次数，仅在`status`为`'expired'`时有效 默认值：`0`.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdQRCode'
    IconSize = TypedDict(
        'IconSize', {'width': NotRequired[NumberType], 'height': NotRequired[NumberType]}
    )

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        locale: typing.Optional[Literal['zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr']] = None,
        value: typing.Optional[str] = None,
        type: typing.Optional[Literal['canvas', 'svg']] = None,
        icon: typing.Optional[str] = None,
        size: typing.Optional[NumberType] = None,
        iconSize: typing.Optional[typing.Union[NumberType, 'IconSize']] = None,
        color: typing.Optional[str] = None,
        bgColor: typing.Optional[str] = None,
        bordered: typing.Optional[bool] = None,
        errorLevel: typing.Optional[Literal['L', 'M', 'Q', 'H']] = None,
        status: typing.Optional[Literal['active', 'expired', 'loading', 'scanned']] = None,
        expires: typing.Optional[NumberType] = None,
        autoSpin: typing.Optional[bool] = None,
        refreshClicks: typing.Optional[NumberType] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'locale',
            'value',
            'type',
            'icon',
            'size',
            'iconSize',
            'color',
            'bgColor',
            'bordered',
            'errorLevel',
            'status',
            'expires',
            'autoSpin',
            'refreshClicks',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'locale',
            'value',
            'type',
            'icon',
            'size',
            'iconSize',
            'color',
            'bgColor',
            'bordered',
            'errorLevel',
            'status',
            'expires',
            'autoSpin',
            'refreshClicks',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdQRCode, self).__init__(**args)


setattr(AntdQRCode, '__init__', _explicitize_args(AntdQRCode.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdBreadcrumb(Component):
    """An AntdBreadcrumb component.
    面包屑组件AntdBreadcrumb

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - items (list of dicts; optional):
        面包屑节点数据结构.

        `items` is a list of dicts with keys:

        - title (string; optional):
            节点标题.

        - key (string; optional):
            节点唯一key值.

        - href (string; optional):
            节点链接地址.

        - target (string; optional):
            节点链接跳转行为.

        - icon (string; optional):
            节点前缀图标名称，与`iconRenderer`方式相关联，`'AntdIcon'`方式下同AntdIcon的icon参数，`'fontawesome'`方式下代表图标的css类名.

        - iconRenderer (a value equal to: 'AntdIcon', 'fontawesome'; optional):
            前缀图标渲染方式，可选项有`'AntdIcon'`、`'fontawesome'` 默认值：`'AntdIcon'`.

        - menuItems (list of dicts; optional):
            为当前节点设置下拉菜单生成所需的数据结构.

            `menuItems` is a list of dicts with keys:

            - title (string; optional):

                下拉菜单节点标题.

            - key (string; optional):

                下拉菜单节点唯一key值.

            - href (string; optional):

                下拉菜单节点链接地址.

            - target (string; optional):

                下拉菜单节点链接跳转方式.

            - disabled (boolean; optional):

                是否禁用当前下拉菜单节点.

            - icon (string; optional):

                下拉菜单节点前缀图标名称，与`iconRenderer`方式相关联，`'AntdIcon'`方式下同AntdIcon的icon参数，`'fontawesome'`方式下代表图标的css类名.

            - iconRenderer (a value equal to: 'AntdIcon', 'fontawesome'; optional):

                前缀图标渲染方式，可选项有`'AntdIcon'`、`'fontawesome'` 默认值：`'AntdIcon'`.

    - separator (a list of or a singular dash component, string or number; default '/'):
        组件型，分隔符 默认值：`'/'`.

    - clickedItem (dict; optional):
        监听面包屑节点点击事件.

        `clickedItem` is a dict with keys:

        - itemTitle (string; optional):
            对应节点标题.

        - itemKey (string; optional):
            对应节点key值.

        - menuItemTitle (string; optional):
            对应下拉菜单节点标题.

        - menuItemKey (string; optional):
            对应下拉菜单节点key值.

        - timestamp (number; optional):
            点击事件时间戳.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = ['separator']
    _base_nodes = ['separator', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdBreadcrumb'
    ItemsMenuItems = TypedDict(
        'ItemsMenuItems',
        {
            'title': NotRequired[str],
            'key': NotRequired[str],
            'href': NotRequired[str],
            'target': NotRequired[str],
            'disabled': NotRequired[bool],
            'icon': NotRequired[str],
            'iconRenderer': NotRequired[Literal['AntdIcon', 'fontawesome']],
        },
    )

    Items = TypedDict(
        'Items',
        {
            'title': NotRequired[str],
            'key': NotRequired[str],
            'href': NotRequired[str],
            'target': NotRequired[str],
            'icon': NotRequired[str],
            'iconRenderer': NotRequired[Literal['AntdIcon', 'fontawesome']],
            'menuItems': NotRequired[typing.Sequence['ItemsMenuItems']],
        },
    )

    ClickedItem = TypedDict(
        'ClickedItem',
        {
            'itemTitle': NotRequired[str],
            'itemKey': NotRequired[str],
            'menuItemTitle': NotRequired[str],
            'menuItemKey': NotRequired[str],
            'timestamp': NotRequired[NumberType],
        },
    )

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        items: typing.Optional[typing.Sequence['Items']] = None,
        separator: typing.Optional[ComponentType] = None,
        clickedItem: typing.Optional['ClickedItem'] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'items',
            'separator',
            'clickedItem',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'items',
            'separator',
            'clickedItem',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdBreadcrumb, self).__init__(**args)


setattr(AntdBreadcrumb, '__init__', _explicitize_args(AntdBreadcrumb.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdCalendar(Component):
    """An AntdCalendar component.
    日历组件AntdCalendar

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - name (string; optional):
        配合`AntdForm`表单批量值搜集/控制功能使用，充当当前表单项的字段名，以`id`作为缺省值.

    - enableBatchControl (boolean; default True):
        控制当前组件是否参与有效的`AntdForm`表单批量值搜集/控制功能 默认值：`True`.

    - locale (a value equal to: 'zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr'; default 'zh-cn'):
        组件文案语种，可选项有`'zh-cn'`（简体中文）、`'en-us'`（英语）、`'de-de'`（德语）、`'fr-fr'`（法语）、`'ru-ru'`（俄语）
        默认值：`'zh-cn'`.

    - format (string; default 'YYYY-MM-DD'):
        日期显示格式，[参考资料](https://day.js.org/docs/en/display/format)
        默认值：`'YYYY-MM-DD'`.

    - size (a value equal to: 'default', 'large'; default 'default'):
        日历尺寸规格，可选项有`'default'`、`'large'` 默认值：`'default'`.

    - value (string; optional):
        监听或设置当前选中日期值.

    - defaultValue (string; optional):
        初始化选中日期值.

    - customCells (list of dicts; optional):
        自定义对应月份、日期的单元格显示内容.

        `customCells` is a list of dicts with keys:

        - type (a value equal to: 'month', 'date'; required):
            必填，当前项对应类型，可选项有`'month'`、`'date'`.

        - year (number; optional):
            当前项匹配的年份值.

        - month (number; optional):
            当前项匹配的月份值.

        - date (number; optional):
            当前项匹配的日期值.

        - content (a list of or a singular dash component, string or number; optional):
            自定义内容.

    - cellClickEvent (dict; optional):
        监听日期单元格点击事件.

        `cellClickEvent` is a dict with keys:

        - type (string; optional):
            记录面板类型.

        - timestamp (number; optional):
            事件发生时间戳.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配.

    - persistence (boolean | string | number; optional):
        是否开启[属性持久化](/prop-persistence).

    - persisted_props (list of a value equal to: 'value's; optional):
        开启属性持久化功能的若干属性名，可选项有`'value'` 默认值：`['value']`.

    - persistence_type (a value equal to: 'local', 'session', 'memory'; optional):
        属性持久化存储类型，可选项有`'local'`（本地持久化），`'session'`（会话持久化），`'memory'`（内存持久化）
        默认值：`'local'`."""

    _children_props: typing.List[str] = ['customCells[].content']
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdCalendar'
    CustomCells = TypedDict(
        'CustomCells',
        {
            'type': Literal['month', 'date'],
            'year': NotRequired[NumberType],
            'month': NotRequired[NumberType],
            'date': NotRequired[NumberType],
            'content': NotRequired[ComponentType],
        },
    )

    CellClickEvent = TypedDict(
        'CellClickEvent', {'type': NotRequired[str], 'timestamp': NotRequired[NumberType]}
    )

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        name: typing.Optional[str] = None,
        enableBatchControl: typing.Optional[bool] = None,
        locale: typing.Optional[Literal['zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr']] = None,
        format: typing.Optional[str] = None,
        size: typing.Optional[Literal['default', 'large']] = None,
        value: typing.Optional[str] = None,
        defaultValue: typing.Optional[str] = None,
        customCells: typing.Optional[typing.Sequence['CustomCells']] = None,
        cellClickEvent: typing.Optional['CellClickEvent'] = None,
        persistence: typing.Optional[typing.Union[bool, str, NumberType]] = None,
        persisted_props: typing.Optional[typing.Sequence[Literal['value']]] = None,
        persistence_type: typing.Optional[Literal['local', 'session', 'memory']] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'name',
            'enableBatchControl',
            'locale',
            'format',
            'size',
            'value',
            'defaultValue',
            'customCells',
            'cellClickEvent',
            'data-*',
            'aria-*',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'name',
            'enableBatchControl',
            'locale',
            'format',
            'size',
            'value',
            'defaultValue',
            'customCells',
            'cellClickEvent',
            'data-*',
            'aria-*',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdCalendar, self).__init__(**args)


setattr(AntdCalendar, '__init__', _explicitize_args(AntdCalendar.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdDraggerUpload(Component):
    """An AntdDraggerUpload component.
    文件拖拽上传组件AntdDraggerUpload

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - name (string; optional):
        配合`AntdForm`表单批量值搜集/控制功能使用，充当当前表单项的字段名，以`id`作为缺省值.

    - enableBatchControl (boolean; default True):
        控制当前组件是否参与有效的`AntdForm`表单批量值搜集/控制功能 默认值：`True`.

    - draggerClassName (string | dict; optional):
        拖拽区域css类名，支持[动态css](/advanced-classname).

    - draggerStyle (dict; optional):
        拖拽区域css样式.

    - locale (a value equal to: 'zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr'; default 'zh-cn'):
        组件文案语种，可选项有`'zh-cn'`（简体中文）、`'en-us'`（英语）、`'de-de'`（德语）、`'fr-fr'`（法语）、`'ru-ru'`（俄语）
        默认值：`'zh-cn'`.

    - apiUrl (string; optional):
        文件上传服务接口地址.

    - apiUrlExtraParams (dict; optional):
        文件上传服务接口额外参数.

    - headers (dict; optional):
        文件上传服务接口额外headers参数.

    - withCredentials (boolean; default False):
        是否在请求上传服务接口时自动携带cookies等凭据信息 默认值：`False`.

    - withOriginFileObj (boolean; default False):
        `listUploadTaskRecord`监听结果中是否额外记录浏览器原生`originFileObj`相关信息
        默认值：`False`.

    - downloadUrl (string; optional):
        对应已上传文件的`GET`类型下载服务接口地址，自带参数`taskId`、`filename`.

    - downloadUrlExtraParams (dict; optional):
        配合`downloadUrl`参数，设置文件下载服务接口额外参数.

    - downloadUrlFromBackend (boolean; default False):
        是否将文件上传接口返回信息中的`url`属性作为下载链接地址 默认值：`False`.

    - icon (a list of or a singular dash component, string or number; optional):
        组件型，自定义上传图标.

    - text (a list of or a singular dash component, string or number; optional):
        组件型，上传区域主要文字说明内容.

    - hint (a list of or a singular dash component, string or number; optional):
        组件型，上传区域次要文字说明内容.

    - fileListMaxLength (number; optional):
        限制已上传文件列表长度上限.

    - fileTypes (list of strings; optional):
        允许上传的文件后缀名列表，默认不限制.

    - uploadId (string; optional):
        自定义当前组件发起文件上传请求时携带的`uploadId`参数，可用于辅助后端创建文件上传所在文件夹.

    - fileMaxSize (number; default 500):
        文件上传尺寸上限，单位：兆.

    - multiple (boolean; default False):
        是否开启多文件上传模式 默认值：`False`.

    - directory (boolean; default False):
        是否开启文件夹上传模式 默认值：`False`.

    - failedTooltipInfo (string; optional):
        文件上传失败消息提示文字内容 默认值：`'上传失败'`.

    - showUploadList (boolean; default True):
        是否显示已上传文件列表 默认值：`True`.

    - confirmBeforeDelete (boolean; default False):
        是否为已上传文件删除操作添加二次确认模态框 默认值：`False`.

    - showPercent (boolean; default False):
        是否显示上传进度条 默认值：`False`.

    - progressProps (dict; optional):
        配置上传进度条相关参数.

        `progressProps` is a dict with keys:

        - strokeColor (dict; optional):
            进度条颜色.

            `strokeColor` is a string

          Or dict with keys:

            - from (string; optional):

                渐变色开始颜色.

            - to (string; optional):

                渐变色结束颜色.

        - strokeWidth (number; optional):
            进度条像素宽度.

        - format (dict; optional):
            进度文字格式.

            `format` is a dict with keys:

            - prefix (string; optional):
                进度文字前缀内容.

            - suffix (string; optional):
                进度文字后缀内容 默认值：`'%'`.

    - showSuccessMessage (boolean; default True):
        是否在每个文件上传成功后，分别弹出消息提示 默认值：`True`.

    - showErrorMessage (boolean; default True):
        是否在每个文件上传失败后，分别弹出消息提示 默认值：`True`.

    - pastable (boolean; default False):
        是否开启粘贴上传，即本地复制文件后，在页面任意位置粘贴即可完成上传 默认值：`False`.

    - lastUploadTaskRecord (dict; optional):
        监听最近一次文件上传任务相关信息.

        `lastUploadTaskRecord` is a dict with keys:

        - fileName (string; optional):
            文件名称.

        - fileSize (number; optional):
            文件大小.

        - completeTimestamp (number; optional):
            上传完成时间戳.

        - taskStatus (string; optional):
            上传任务状态，`'success'`表示成功，`'failed'`表示失败.

        - taskId (string; optional):
            上传任务唯一识别id，当任务状态为`'failed'`时不会携带此信息.

        - url (string; optional):
            当前文件的下载链接.

        - uploadResponse (boolean | number | string | dict | list; optional):
            上传任务的接口响应信息. | list of dicts with keys:

        - fileName (string; optional):
            文件名称.

        - fileSize (number; optional):
            文件大小.

        - completeTimestamp (number; optional):
            上传完成时间戳.

        - taskStatus (string; optional):
            上传任务状态，`'success'`表示成功，`'failed'`表示失败.

        - taskId (string; optional):
            上传任务唯一识别id，当任务状态为`'failed'`时不会携带此信息.

        - url (string; optional):
            当前文件的下载链接.

        - uploadResponse (boolean | number | string | dict | list; optional):
            上传任务的接口响应信息.

    - listUploadTaskRecord (list of dicts; optional):
        监听当前已上传文件列表中上传任务相关信息.

        `listUploadTaskRecord` is a list of dicts with keys:

        - fileName (string; optional):
            文件名称.

        - fileSize (number; optional):
            文件大小.

        - completeTimestamp (number; optional):
            上传完成时间戳.

        - taskStatus (string; optional):
            上传任务状态，`'success'`表示成功，`'failed'`表示失败.

        - taskId (string; optional):
            上传任务唯一识别id，当任务状态为`'failed'`时不会携带此信息.

        - uid (string; optional):
            当前文件上传唯一识别id，前端自动生成.

        - url (string; optional):
            当前文件下载链接.

        - uploadResponse (boolean | number | string | dict | list; optional):
            上传任务的接口响应信息.

        - originFileObj (boolean | number | string | dict | list; optional):
            当`withOriginFileObj=True`时，监听当前文件上传任务对应的`originFileObj`主要信息.

    - defaultFileList (list of dicts; optional):
        初始化文件列表展示信息.

        `defaultFileList` is a list of dicts with keys:

        - name (string; optional):
            当前文件名称.

        - status (a value equal to: 'done', 'error', 'removed'; optional):
            当前文件展示状态，可选项有`'done'`、`'error'`、`'removed'`.

        - uid (boolean | number | string | dict | list; optional):
            当前文件唯一识别id.

        - url (string; optional):
            当前文件下载链接.

        - taskId (string; optional):
            若传入有效值，将作为当前组件的`uploadId`参数.

        - fileSize (number; optional):
            当前文件大小.

    - disabled (boolean; default False):
        是否禁用当前组件 默认值：`False`.

    - status (a value equal to: 'error', 'warning'; optional):
        控制校验状态，可选项有`'error'`、`'warning'`.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = ['icon', 'text', 'hint']
    _base_nodes = ['icon', 'text', 'hint', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdDraggerUpload'
    ProgressPropsStrokeColor = TypedDict(
        'ProgressPropsStrokeColor', {'from': NotRequired[str], 'to': NotRequired[str]}
    )

    ProgressPropsFormat = TypedDict(
        'ProgressPropsFormat', {'prefix': NotRequired[str], 'suffix': NotRequired[str]}
    )

    ProgressProps = TypedDict(
        'ProgressProps',
        {
            'strokeColor': NotRequired[typing.Union[str, 'ProgressPropsStrokeColor']],
            'strokeWidth': NotRequired[NumberType],
            'format': NotRequired['ProgressPropsFormat'],
        },
    )

    LastUploadTaskRecord = TypedDict(
        'LastUploadTaskRecord',
        {
            'fileName': NotRequired[str],
            'fileSize': NotRequired[NumberType],
            'completeTimestamp': NotRequired[NumberType],
            'taskStatus': NotRequired[str],
            'taskId': NotRequired[str],
            'url': NotRequired[str],
            'uploadResponse': NotRequired[typing.Any],
        },
    )

    ListUploadTaskRecord = TypedDict(
        'ListUploadTaskRecord',
        {
            'fileName': NotRequired[str],
            'fileSize': NotRequired[NumberType],
            'completeTimestamp': NotRequired[NumberType],
            'taskStatus': NotRequired[str],
            'taskId': NotRequired[str],
            'uid': NotRequired[str],
            'url': NotRequired[str],
            'uploadResponse': NotRequired[typing.Any],
            'originFileObj': NotRequired[typing.Any],
        },
    )

    DefaultFileList = TypedDict(
        'DefaultFileList',
        {
            'name': NotRequired[str],
            'status': NotRequired[Literal['done', 'error', 'removed']],
            'uid': NotRequired[typing.Any],
            'url': NotRequired[str],
            'taskId': NotRequired[str],
            'fileSize': NotRequired[NumberType],
        },
    )

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        name: typing.Optional[str] = None,
        enableBatchControl: typing.Optional[bool] = None,
        draggerClassName: typing.Optional[typing.Union[str, dict]] = None,
        draggerStyle: typing.Optional[dict] = None,
        locale: typing.Optional[Literal['zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr']] = None,
        apiUrl: typing.Optional[str] = None,
        apiUrlExtraParams: typing.Optional[dict] = None,
        headers: typing.Optional[dict] = None,
        withCredentials: typing.Optional[bool] = None,
        withOriginFileObj: typing.Optional[bool] = None,
        downloadUrl: typing.Optional[str] = None,
        downloadUrlExtraParams: typing.Optional[dict] = None,
        downloadUrlFromBackend: typing.Optional[bool] = None,
        icon: typing.Optional[ComponentType] = None,
        text: typing.Optional[ComponentType] = None,
        hint: typing.Optional[ComponentType] = None,
        fileListMaxLength: typing.Optional[NumberType] = None,
        fileTypes: typing.Optional[typing.Sequence[str]] = None,
        uploadId: typing.Optional[str] = None,
        fileMaxSize: typing.Optional[NumberType] = None,
        multiple: typing.Optional[bool] = None,
        directory: typing.Optional[bool] = None,
        failedTooltipInfo: typing.Optional[str] = None,
        showUploadList: typing.Optional[bool] = None,
        confirmBeforeDelete: typing.Optional[bool] = None,
        showPercent: typing.Optional[bool] = None,
        progressProps: typing.Optional['ProgressProps'] = None,
        showSuccessMessage: typing.Optional[bool] = None,
        showErrorMessage: typing.Optional[bool] = None,
        pastable: typing.Optional[bool] = None,
        lastUploadTaskRecord: typing.Optional[
            typing.Union['LastUploadTaskRecord', typing.Sequence['LastUploadTaskRecord']]
        ] = None,
        listUploadTaskRecord: typing.Optional[typing.Sequence['ListUploadTaskRecord']] = None,
        defaultFileList: typing.Optional[typing.Sequence['DefaultFileList']] = None,
        disabled: typing.Optional[bool] = None,
        status: typing.Optional[Literal['error', 'warning']] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'name',
            'enableBatchControl',
            'draggerClassName',
            'draggerStyle',
            'locale',
            'apiUrl',
            'apiUrlExtraParams',
            'headers',
            'withCredentials',
            'withOriginFileObj',
            'downloadUrl',
            'downloadUrlExtraParams',
            'downloadUrlFromBackend',
            'icon',
            'text',
            'hint',
            'fileListMaxLength',
            'fileTypes',
            'uploadId',
            'fileMaxSize',
            'multiple',
            'directory',
            'failedTooltipInfo',
            'showUploadList',
            'confirmBeforeDelete',
            'showPercent',
            'progressProps',
            'showSuccessMessage',
            'showErrorMessage',
            'pastable',
            'lastUploadTaskRecord',
            'listUploadTaskRecord',
            'defaultFileList',
            'disabled',
            'status',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'name',
            'enableBatchControl',
            'draggerClassName',
            'draggerStyle',
            'locale',
            'apiUrl',
            'apiUrlExtraParams',
            'headers',
            'withCredentials',
            'withOriginFileObj',
            'downloadUrl',
            'downloadUrlExtraParams',
            'downloadUrlFromBackend',
            'icon',
            'text',
            'hint',
            'fileListMaxLength',
            'fileTypes',
            'uploadId',
            'fileMaxSize',
            'multiple',
            'directory',
            'failedTooltipInfo',
            'showUploadList',
            'confirmBeforeDelete',
            'showPercent',
            'progressProps',
            'showSuccessMessage',
            'showErrorMessage',
            'pastable',
            'lastUploadTaskRecord',
            'listUploadTaskRecord',
            'defaultFileList',
            'disabled',
            'status',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdDraggerUpload, self).__init__(**args)


setattr(AntdDraggerUpload, '__init__', _explicitize_args(AntdDraggerUpload.__init__))



import json
from pathlib import Path

from setuptools import setup

here = Path(__file__).parent
with open('package.json') as f:
    package = json.load(f)
long_description = (here / 'README.md').read_text(encoding='utf-8')

package_name = package['name'].replace(' ', '_').replace('-', '_')

setup(
    name=package_name,
    version=package['version'],
    homepage=package['homepage'],
    author=package['author'],
    packages=[package_name],
    include_package_data=True,
    package_data={'feffery_antd_components': ['*']},
    license=package['license'],
    description=package.get('description', package_name),
    long_description=long_description,
    long_description_content_type='text/markdown',
    install_requires=[
        'dash>=3.3.0',
    ],
    classifiers=[
        'Framework :: Dash',
    ],
    url='https://github.com/CNFeffery/feffery-antd-components',
)



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdSelect(Component):
    """An AntdSelect component.
    下拉选择组件AntdSelect

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果F.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - popupClassName (string; optional):
        展开菜单css类名.

    - name (string; optional):
        配合`AntdForm`表单批量值搜集/控制功能使用，充当当前表单项的字段名，以`id`作为缺省值.

    - enableBatchControl (boolean; default True):
        控制当前组件是否参与有效的`AntdForm`表单批量值搜集/控制功能 默认值：`True`.

    - locale (a value equal to: 'zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr'; default 'zh-cn'):
        组件文案语种，可选项有`'zh-cn'`（简体中文）、`'en-us'`（英语）、`'de-de'`（德语）、`'fr-fr'`（法语）、`'ru-ru'`（俄语）
        默认值：`'zh-cn'`.

    - options (list of dicts; optional):
        配置下拉选项.

        `options` is a list of string | number | dict with keys:

        - label (a list of or a singular dash component, string or number; required):
            组件型，当前选项标签内容.

        - value (string

          Or number; required):
            当前选项值.

        - disabled (boolean; optional):
            是否禁用当前选项 默认值：`False`.

        - colors (list of strings; optional):
            针对色带特殊渲染模式，设置生成渐变色带所需的色彩值数组. | dict with keys:

        - group (a list of or a singular dash component, string or number; optional):
            组件型，当前分组标签内容.

        - options (list of dicts; optional):
            配置当前分组内选项.

            `options` is a list of dicts with keys:

            - label (a list of or a singular dash component, string or number; required):

                组件型，当前选项标签内容.

            - value (string | number; required):

                当前选项值.

            - disabled (boolean; optional):

                是否禁用当前选项 默认值：`False`.

            - colors (list of strings; optional):

                针对色带特殊渲染模式，设置生成渐变色带所需的色彩值数组.s

    - listHeight (number; default 256):
        下拉菜单最大像素高度.

    - colorsMode (a value equal to: 'sequential', 'diverging'; default 'sequential'):
        色带特殊渲染模式下，设置渲染形式，可选项有`'sequential'`、`'diverging'`.

    - colorsNameWidth (number; default 40):
        色带特殊渲染模式下，设置各选项名称部分像素宽度 默认值：`40`.

    - mode (a value equal to: 'multiple', 'tags'; optional):
        选择模式，可选项有`'multiple'`（多选）、`'tags'`（自由新增）.

    - disabled (boolean; optional):
        是否禁用当前组件 默认值：`False`.

    - size (a value equal to: 'small', 'middle', 'large'; default 'middle'):
        当前组件尺寸规格，可选项有`'small'`、`'middle'`、`'large'` 默认值：`'middle'`.

    - bordered (boolean; default True):
        是否显示边框，设置为`True`时等价于`variant='outlined'` 默认值：`True`.

    - variant (a value equal to: 'outlined', 'borderless', 'filled', 'underlined'; optional):
        形态变体类型，可选项有`'outlined'`、`'borderless'`、`'filled'`、`'underlined'`，其中`'outlined'`等价于`bordered=True`，但优先级更高.

    - placeholder (string; optional):
        输入框占位文字内容.

    - placement (a value equal to: 'bottomLeft', 'bottomRight', 'topLeft', 'topRight'; default 'bottomLeft'):
        选择面板展开方向，可选项有`'bottomLeft'`、`'bottomRight'`、`'topLeft'`、`'topRight'`
        默认值：`'bottomLeft'`.

    - value (string | number | list of string | numbers; optional):
        监听或设置已选值.

    - defaultValue (string | number | list of string | numbers; optional):
        初始化已选值.

    - maxTagCount (number | a value equal to: 'responsive'; default 5):
        当`multiple=True`时，已选值展示的最大数量 默认值：`5`.

    - status (a value equal to: 'error', 'warning'; optional):
        控制校验状态，可选项有`'error'`、`'warning'`.

    - optionFilterProp (a value equal to: 'value', 'label'; default 'value'):
        基于搜索框中输入内容进行搜索的目标字段，可选项有`'value'`、`'label'` 默认值：`'value'`.

    - searchValue (string; optional):
        监听搜索框已输入内容.

    - optionFilterMode (a value equal to: 'case-insensitive', 'case-sensitive', 'regex', 'remote-match'; default 'case-insensitive'):
        搜索匹配模式，可选项有`'case-insensitive'`（大小写不敏感）、`'case-sensitive'`（大小写敏感）、`'regex'`（正则表达式）、`'remote-match'`（远程匹配模式）
        默认值：`'case-insensitive'`.

    - debounceSearchValue (string; optional):
        以防抖延时的方式监听搜索框已输入内容.

    - debounceWait (number; default 0):
        防抖延时时长，单位：毫秒 默认值：`0`.

    - autoSpin (boolean; default False):
        是否在当前组件相关属性处理回调更新中状态时，以加载中状态进行渲染 默认值：`False`.

    - autoClearSearchValue (boolean; default True):
        当`mode`为`'multiple'`或`'tags'`时，设置是否在选中项后自动清空搜索框中的内容 默认值：`True`.

    - emptyContent (a list of or a singular dash component, string or number; optional):
        组件型，自定义空数据状态提示内容.

    - loadingEmptyContent (a list of or a singular dash component, string or number; optional):
        组件型，自定义加载中状态下的空数据状态提示内容.

    - dropdownBefore (a list of or a singular dash component, string or number; optional):
        组件型，选择菜单前缀内容.

    - dropdownAfter (a list of or a singular dash component, string or number; optional):
        组件型，选择菜单后缀内容.

    - prefix (a list of or a singular dash component, string or number; optional):
        组件型，前缀内嵌内容.

    - suffixIcon (a list of or a singular dash component, string or number; optional):
        自定义选择框后缀图标内容.

    - allowClear (boolean; default True):
        是否允许一键清空已选值 默认值：`True`.

    - autoFocus (boolean; default False):
        是否自动获取焦点 默认值：`False`.

    - popupMatchSelectWidth (boolean; default True):
        选择菜单是否与选择框同宽，设置为`False`时将关闭虚拟滚动功能 默认值：`True`.

    - readOnly (boolean; optional):
        是否渲染为只读状态 默认值：`False`.

    - maxCount (number; optional):
        `'multiple'`及 `'tags'`模式下有效，限制已选项数量上限.

    - showSearch (boolean; optional):
        是否开启输入框可搜索功能.

    - popupContainer (a value equal to: 'parent', 'body'; default 'body'):
        相关展开层锚定策略，可选项有`'parent'`、`'body'` 默认值：`'body'`.

    - batchPropsNames (list of strings; optional):
        需要纳入[批量属性监听](/batch-props-values)的若干属性名.

    - batchPropsValues (dict; optional):
        监听`batchPropsNames`中指定的若干属性值.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配.

    - persistence (boolean | string | number; optional):
        是否开启[属性持久化](/prop-persistence).

    - persisted_props (list of a value equal to: 'value's; optional):
        开启属性持久化功能的若干属性名，可选项有`'value'` 默认值：`['value']`.

    - persistence_type (a value equal to: 'local', 'session', 'memory'; optional):
        属性持久化存储类型，可选项有`'local'`（本地持久化），`'session'`（会话持久化），`'memory'`（内存持久化）
        默认值：`'local'`."""

    _children_props: typing.List[str] = [
        'options[].label',
        'options[].group',
        'options[].options[].label',
        'emptyContent',
        'loadingEmptyContent',
        'dropdownBefore',
        'dropdownAfter',
        'prefix',
        'suffixIcon',
    ]
    _base_nodes = [
        'emptyContent',
        'loadingEmptyContent',
        'dropdownBefore',
        'dropdownAfter',
        'prefix',
        'suffixIcon',
        'children',
    ]
    _namespace = 'feffery_antd_components'
    _type = 'AntdSelect'
    Options = TypedDict(
        'Options',
        {
            'group': NotRequired[ComponentType],
            'options': NotRequired[typing.Sequence['OptionsOptions']],
        },
    )

    OptionsOptions = TypedDict(
        'OptionsOptions',
        {
            'label': ComponentType,
            'value': typing.Union[str, NumberType],
            'disabled': NotRequired[bool],
            'colors': NotRequired[typing.Sequence[str]],
        },
    )

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        popupClassName: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        enableBatchControl: typing.Optional[bool] = None,
        locale: typing.Optional[Literal['zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr']] = None,
        options: typing.Optional[typing.Sequence[typing.Union[str, NumberType, 'Options']]] = None,
        listHeight: typing.Optional[NumberType] = None,
        colorsMode: typing.Optional[Literal['sequential', 'diverging']] = None,
        colorsNameWidth: typing.Optional[NumberType] = None,
        mode: typing.Optional[Literal['multiple', 'tags']] = None,
        disabled: typing.Optional[bool] = None,
        size: typing.Optional[Literal['small', 'middle', 'large']] = None,
        bordered: typing.Optional[bool] = None,
        variant: typing.Optional[Literal['outlined', 'borderless', 'filled', 'underlined']] = None,
        placeholder: typing.Optional[str] = None,
        placement: typing.Optional[
            Literal['bottomLeft', 'bottomRight', 'topLeft', 'topRight']
        ] = None,
        value: typing.Optional[
            typing.Union[
                typing.Union[str, NumberType], typing.Sequence[typing.Union[str, NumberType]]
            ]
        ] = None,
        defaultValue: typing.Optional[
            typing.Union[
                typing.Union[str, NumberType], typing.Sequence[typing.Union[str, NumberType]]
            ]
        ] = None,
        maxTagCount: typing.Optional[typing.Union[NumberType, Literal['responsive']]] = None,
        status: typing.Optional[Literal['error', 'warning']] = None,
        optionFilterProp: typing.Optional[Literal['value', 'label']] = None,
        searchValue: typing.Optional[str] = None,
        optionFilterMode: typing.Optional[
            Literal['case-insensitive', 'case-sensitive', 'regex', 'remote-match']
        ] = None,
        debounceSearchValue: typing.Optional[str] = None,
        debounceWait: typing.Optional[NumberType] = None,
        autoSpin: typing.Optional[bool] = None,
        autoClearSearchValue: typing.Optional[bool] = None,
        emptyContent: typing.Optional[ComponentType] = None,
        loadingEmptyContent: typing.Optional[ComponentType] = None,
        dropdownBefore: typing.Optional[ComponentType] = None,
        dropdownAfter: typing.Optional[ComponentType] = None,
        prefix: typing.Optional[ComponentType] = None,
        suffixIcon: typing.Optional[ComponentType] = None,
        allowClear: typing.Optional[bool] = None,
        autoFocus: typing.Optional[bool] = None,
        popupMatchSelectWidth: typing.Optional[bool] = None,
        readOnly: typing.Optional[bool] = None,
        maxCount: typing.Optional[NumberType] = None,
        showSearch: typing.Optional[bool] = None,
        popupContainer: typing.Optional[Literal['parent', 'body']] = None,
        batchPropsNames: typing.Optional[typing.Sequence[str]] = None,
        batchPropsValues: typing.Optional[dict] = None,
        persistence: typing.Optional[typing.Union[bool, str, NumberType]] = None,
        persisted_props: typing.Optional[typing.Sequence[Literal['value']]] = None,
        persistence_type: typing.Optional[Literal['local', 'session', 'memory']] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'popupClassName',
            'name',
            'enableBatchControl',
            'locale',
            'options',
            'listHeight',
            'colorsMode',
            'colorsNameWidth',
            'mode',
            'disabled',
            'size',
            'bordered',
            'variant',
            'placeholder',
            'placement',
            'value',
            'defaultValue',
            'maxTagCount',
            'status',
            'optionFilterProp',
            'searchValue',
            'optionFilterMode',
            'debounceSearchValue',
            'debounceWait',
            'autoSpin',
            'autoClearSearchValue',
            'emptyContent',
            'loadingEmptyContent',
            'dropdownBefore',
            'dropdownAfter',
            'prefix',
            'suffixIcon',
            'allowClear',
            'autoFocus',
            'popupMatchSelectWidth',
            'readOnly',
            'maxCount',
            'showSearch',
            'popupContainer',
            'batchPropsNames',
            'batchPropsValues',
            'data-*',
            'aria-*',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'popupClassName',
            'name',
            'enableBatchControl',
            'locale',
            'options',
            'listHeight',
            'colorsMode',
            'colorsNameWidth',
            'mode',
            'disabled',
            'size',
            'bordered',
            'variant',
            'placeholder',
            'placement',
            'value',
            'defaultValue',
            'maxTagCount',
            'status',
            'optionFilterProp',
            'searchValue',
            'optionFilterMode',
            'debounceSearchValue',
            'debounceWait',
            'autoSpin',
            'autoClearSearchValue',
            'emptyContent',
            'loadingEmptyContent',
            'dropdownBefore',
            'dropdownAfter',
            'prefix',
            'suffixIcon',
            'allowClear',
            'autoFocus',
            'popupMatchSelectWidth',
            'readOnly',
            'maxCount',
            'showSearch',
            'popupContainer',
            'batchPropsNames',
            'batchPropsValues',
            'data-*',
            'aria-*',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdSelect, self).__init__(**args)


setattr(AntdSelect, '__init__', _explicitize_args(AntdSelect.__init__))



from __future__ import print_function as _

import json
import os as _os
import sys as _sys

import dash as _dash

# noinspection PyUnresolvedReferences
from ._imports_ import *  # noqa: F403
from ._imports_ import __all__

if not hasattr(_dash, '__plotly_dash') and not hasattr(_dash, 'development'):
    print(
        'Dash was not successfully imported. '
        "Make sure you don't have a file "
        'named \n"dash.py" in your current directory.',
        file=_sys.stderr,
    )
    _sys.exit(1)

_basepath = _os.path.dirname(__file__)
_filepath = _os.path.abspath(_os.path.join(_basepath, 'package-info.json'))
with open(_filepath) as f:
    package = json.load(f)

package_name = package['name'].replace(' ', '_').replace('-', '_')
__version__ = package['version']

_current_path = _os.path.dirname(_os.path.abspath(__file__))

_this_module = _sys.modules[__name__]

async_resources = [
    'antd_table',
    'upload',
    'data_entry',
    'data_display',
]


_js_dist = [
    {
        'relative_package_path': 'feffery_antd_components.min.js',
        'external_url': 'https://unpkg.com/{0}@{2}/{1}/{1}.min.js'.format(
            package_name, __name__, __version__
        ),
        'namespace': package_name,
    },
    {
        'relative_package_path': 'feffery_antd_components.min.js.map',
        'external_url': 'https://unpkg.com/{0}@{2}/{1}/{1}.min.js.map'.format(
            package_name, __name__, __version__
        ),
        'namespace': package_name,
        'dynamic': True,
    },
]

_js_dist.extend(
    [
        {
            'relative_package_path': 'async-{}.js'.format(async_resource),
            'external_url': ('https://unpkg.com/{0}@{2}/{1}/async-{3}.js').format(
                package_name, __name__, __version__, async_resource
            ),
            'namespace': package_name,
            'async': True,
        }
        for async_resource in async_resources
    ]
)

_js_dist.extend(
    [
        {
            'relative_package_path': 'async-{}.js.map'.format(async_resource),
            'external_url': ('https://unpkg.com/{0}@{2}/{1}/async-{3}.js.map').format(
                package_name, __name__, __version__, async_resource
            ),
            'namespace': package_name,
            'dynamic': True,
        }
        for async_resource in async_resources
    ]
)

_css_dist = []


for _component in __all__:
    setattr(locals()[_component], '_js_dist', _js_dist)
    setattr(locals()[_component], '_css_dist', _css_dist)
